"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
import datetime
from PyQt6.QtWidgets import *
import enum


class QCalendarWidget(QWidget):
    """
    https://doc.qt.io/qt-6/qcalendarwidget.html

    **Detailed Description**

    ![](images/fusion-calendarwidget.png)

    The widget is initialized with the current month and year, but
    QCalendarWidget provides several public slots to change the year and month
    that is shown.

    By default, today's date is selected, and the user can select a date using
    both mouse and keyboard. The currently selected date can be retrieved using
    the **selectedDate** () function. It is possible to constrain the user
    selection to a given date range by setting the **minimumDate**  and
    **maximumDate**  properties. Alternatively, both properties can be set in
    one go using the **setDateRange** () convenience slot. Set the
    **selectionMode**  property to **NoSelection**  to prohibit the user from
    selecting at all. Note that a date also can be selected programmatically
    using the **setSelectedDate** () slot.

    The currently displayed month and year can be retrieved using the
    **monthShown** () and **yearShown** () functions, respectively.

    A newly created calendar widget uses abbreviated day names, and both
    Saturdays and Sundays are marked in red. The calendar grid is not visible.
    The week numbers are displayed, and the first column day is the first day of
    the week for the calendar's locale.

    The notation of the days can be altered to a single letter abbreviations
    ("M" for "Monday") by setting the **horizontalHeaderFormat**  property to
    **QCalendarWidget::SingleLetterDayNames** . Setting the same property to
    **QCalendarWidget::LongDayNames**  makes the header display the complete day
    names. The week numbers can be removed by setting the
    **verticalHeaderFormat**  property to **QCalendarWidget::NoVerticalHeader**
    . The calendar grid can be turned on by setting the **gridVisible**
    property to true using the **setGridVisible** () function:

    ![](images/qcalendarwidget-grid.png)


        **QCalendarWidget**
    *calendar;
        calendar->setGridVisible(true);

    Finally, the day in the first column can be altered using the
    **setFirstDayOfWeek** () function.

    The QCalendarWidget class also provides three signals, **selectionChanged**
    (), **activated** () and **currentPageChanged** () making it possible to
    respond to user interaction.

    The rendering of the headers, weekdays or single days can be largely
    customized by setting **QTextCharFormat** 's for some special weekday, a
    special date or for the rendering of the headers.

    Only a subset of the properties in **QTextCharFormat**  are used by the
    calendar widget. Currently, the foreground, background and font properties
    are used to determine the rendering of individual cells in the widget.

    **See also** **QDate** , **QDateEdit** , and **QTextCharFormat** .
    """

    class SelectionMode(enum.Enum):
        NoSelection: QCalendarWidget = ...
        SingleSelection: QCalendarWidget = ...

    class VerticalHeaderFormat(enum.Enum):
        NoVerticalHeader: QCalendarWidget = ...
        ISOWeekNumbers: QCalendarWidget = ...

    class HorizontalHeaderFormat(enum.Enum):
        NoHorizontalHeader: QCalendarWidget = ...
        SingleLetterDayNames: QCalendarWidget = ...
        ShortDayNames: QCalendarWidget = ...
        LongDayNames: QCalendarWidget = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#QCalendarWidget

        **QCalendarWidget::QCalendarWidget(QWidget * parent = nullptr)**

        Constructs a calendar widget with the given **parent**.

        The widget is initialized with the current month and year, and the
        currently selected date is today.

        **See also** **setCurrentPage** ().
        """
        ...

    def setCalendar(self, calendar: QtCore.QCalendar) -> None:
        ...

    def calendar(self) -> QtCore.QCalendar:
        ...

    def setNavigationBarVisible(self, visible: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#navigationBarVisible-prop

        **navigationBarVisible : bool**

        This property holds whether the navigation bar is shown or not

        When this property is `true` (the default), the next month, previous
        month, month selection, year selection controls are shown on top.

        When the property is set to false, these controls are hidden.

        **Access functions:**

        bool **isNavigationBarVisible** () const
        void
        **setNavigationBarVisible** (bool **visible** )
        """
        ...

    def setDateEditAcceptDelay(self, delay: int) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#dateEditAcceptDelay-prop

        **dateEditAcceptDelay : int**

        This property holds the time an inactive date edit is shown before its
        contents are accepted

        If the calendar widget's **date edit is enabled** , this property
        specifies the amount of time (in milliseconds) that the date edit
        remains open after the most recent user input. Once this time has
        elapsed, the date specified in the date edit is accepted and the popup
        is closed.

        By default, the delay is defined to be 1500 milliseconds (1.5 seconds).

        **Access functions:**

        int **dateEditAcceptDelay** () const
        void **setDateEditAcceptDelay**
        (int **delay** )
        """
        ...

    def dateEditAcceptDelay(self) -> int:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#dateEditAcceptDelay-prop

        **dateEditAcceptDelay : int**

        This property holds the time an inactive date edit is shown before its
        contents are accepted

        If the calendar widget's **date edit is enabled** , this property
        specifies the amount of time (in milliseconds) that the date edit
        remains open after the most recent user input. Once this time has
        elapsed, the date specified in the date edit is accepted and the popup
        is closed.

        By default, the delay is defined to be 1500 milliseconds (1.5 seconds).

        **Access functions:**

        int **dateEditAcceptDelay** () const
        void **setDateEditAcceptDelay**
        (int **delay** )
        """
        ...

    def setDateEditEnabled(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#dateEditEnabled-prop

        **dateEditEnabled : bool**

        This property holds whether the date edit popup is enabled

        If this property is enabled, pressing a non-modifier key will cause a
        date edit to popup if the calendar widget has focus, allowing the user
        to specify a date in the form specified by the current locale.

        By default, this property is enabled.

        The date edit is simpler in appearance than **QDateEdit** , but allows
        the user to navigate between fields using the left and right cursor
        keys, increment and decrement individual fields using the up and down
        cursor keys, and enter values directly using the number keys.

        **Access functions:**

        bool **isDateEditEnabled** () const
        void **setDateEditEnabled** (bool
        **enable** )

        **See also** **QCalendarWidget::dateEditAcceptDelay** .
        """
        ...

    def isDateEditEnabled(self) -> bool:
        ...

    def isNavigationBarVisible(self) -> bool:
        ...

    def showToday(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#showToday

        **[slot] void QCalendarWidget::showToday()**

        Shows the month of the today's date.

        **See also** **selectedDate** () and **setCurrentPage** ().
        """
        ...

    def showSelectedDate(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#showSelectedDate

        **[slot] void QCalendarWidget::showSelectedDate()**

        Shows the month of the selected date.

        **See also** **selectedDate** () and **setCurrentPage** ().
        """
        ...

    def showPreviousYear(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#showPreviousYear

        **[slot] void QCalendarWidget::showPreviousYear()**

        Shows the currently displayed month in the **previous** year relative to
        the currently displayed year. Note that the selected date is not
        changed.

        **See also** **showNextYear** (), **setCurrentPage** (), and
        **setSelectedDate** ().
        """
        ...

    def showPreviousMonth(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#showPreviousMonth

        **[slot] void QCalendarWidget::showPreviousMonth()**

        Shows the previous month relative to the currently displayed month. Note
        that the selected date is not changed.

        **See also** **showNextMonth** (), **setCurrentPage** (), and
        **setSelectedDate** ().
        """
        ...

    def showNextYear(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#showNextYear

        **[slot] void QCalendarWidget::showNextYear()**

        Shows the currently displayed month in the **next** year relative to the
        currently displayed year. Note that the selected date is not changed.

        **See also** **showPreviousYear** (), **setCurrentPage** (), and
        **setSelectedDate** ().
        """
        ...

    def showNextMonth(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#showNextMonth

        **[slot] void QCalendarWidget::showNextMonth()**

        Shows the next month relative to the currently displayed month. Note
        that the selected date is not changed.

        **See also** **showPreviousMonth** (), **setCurrentPage** (), and
        **setSelectedDate** ().
        """
        ...

    def setSelectedDate(self, date: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#selectedDate-prop

        **selectedDate : QDate**

        This property holds the currently selected date.

        The selected date must be within the date range specified by the
        **minimumDate**  and **maximumDate**  properties. By default, the
        selected date is the current date.

        **Access functions:**

        QDate **selectedDate** () const
        void **setSelectedDate** (QDate
        **date** )

        **See also** **setDateRange** ().
        """
        ...

    def setDateRange(
        self,
        min: typing.Union[QtCore.QDate, datetime.date],
        max: typing.Union[QtCore.QDate, datetime.date],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#setDateRange

        **[slot] void QCalendarWidget::setDateRange(QDate min , QDate max )**

        Defines a date range by setting the **minimumDate**  and **maximumDate**
        properties.

        The date range restricts the user selection, i.e. the user can only
        select dates within the specified date range. Note that

        **QCalendarWidget**  *calendar;

            calendar->setDateRange(min,
        max);

        is analogous to

        **QCalendarWidget**  *calendar;

            calendar->setMinimumDate(min);
        calendar->setMaximumDate(max);

        If either the **min** or **max** parameters are not valid **QDate**
        objects, this function does nothing.

        **See also** **setMinimumDate** () and **setMaximumDate** ().
        """
        ...

    def setCurrentPage(self, year: int, month: int) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#setCurrentPage

        **[slot] void QCalendarWidget::setCurrentPage(int year , int month )**

        Displays the given **month** of the given **year** without changing the
        selected date. Use the **setSelectedDate** () function to alter the
        selected date.

        The currently displayed month and year can be retrieved using the
        **monthShown** () and **yearShown** () functions respectively.

        **See also** **yearShown** (), **monthShown** (), **showPreviousMonth**
        (), **showNextMonth** (), **showPreviousYear** (), and **showNextYear**
        ().
        """
        ...

    def paintCell(
        self,
        painter: QtGui.QPainter,
        rect: QtCore.QRect,
        date: typing.Union[QtCore.QDate, datetime.date],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#paintCell

        **[virtual protected] void QCalendarWidget::paintCell(QPainter * painter
        , const QRect & rect , QDate date ) const**

        Paints the cell specified by the given **date** , using the given
        **painter** and **rect**.
        """
        ...

    def keyPressEvent(self, event: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#keyPressEvent

        **[override virtual protected] void
        QCalendarWidget::keyPressEvent(QKeyEvent * event )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def resizeEvent(self, event: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#resizeEvent

        **[override virtual protected] void
        QCalendarWidget::resizeEvent(QResizeEvent * event )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).
        """
        ...

    def mousePressEvent(self, event: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#mousePressEvent

        **[override virtual protected] void
        QCalendarWidget::mousePressEvent(QMouseEvent * event )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).
        """
        ...

    def eventFilter(self, watched: QtCore.QObject, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#eventFilter

        **[override virtual protected] bool QCalendarWidget::eventFilter(QObject
        * watched , QEvent * event )**

        Reimplements: **QObject::eventFilter** (QObject *watched, QEvent
        *event).
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#event

        **[override virtual protected] bool QCalendarWidget::event(QEvent *
        event )**

        Reimplements: **QWidget::event** (QEvent *event).
        """
        ...

    def updateCells(self) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#updateCells

        **[protected] void QCalendarWidget::updateCells()**

        Updates all visible cells unless updates are disabled.

        **See also** **updateCell** ().
        """
        ...

    def updateCell(self, date: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#updateCell

        **[protected] void QCalendarWidget::updateCell(QDate date )**

        Updates the cell specified by the given **date** unless updates are
        disabled or the cell is hidden.

        **See also** **updateCells** (), **yearShown** (), and **monthShown**
        ().
        """
        ...

    def setDateTextFormat(
        self,
        date: typing.Union[QtCore.QDate, datetime.date],
        format: QtGui.QTextCharFormat,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#setDateTextFormat

        **void QCalendarWidget::setDateTextFormat(QDate date , const
        QTextCharFormat & format )**

        Sets the format used to render the given **date** to that specified by
        **format**.

        If **date** is null, all date formats are cleared.

        **See also** **dateTextFormat** ().
        """
        ...

    @typing.overload
    def dateTextFormat(self) -> typing.Dict[QtCore.QDate, QtGui.QTextCharFormat]:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#dateTextFormat

        **QMap<QDate, QTextCharFormat> QCalendarWidget::dateTextFormat() const**

        Returns a **QMap**  from **QDate**  to **QTextCharFormat**  showing all
        dates that use a special format that alters their rendering.

        **See also** **setDateTextFormat** ().
        """
        ...

    @typing.overload
    def dateTextFormat(
        self, date: typing.Union[QtCore.QDate, datetime.date]
    ) -> QtGui.QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#dateTextFormat-1

        **QTextCharFormat QCalendarWidget::dateTextFormat(QDate date ) const**

        Returns a **QTextCharFormat**  for **date**. The char format can be be
        empty if the date is not renderd specially.
        """
        ...

    def setWeekdayTextFormat(
        self, dayOfWeek: QtCore.Qt.DayOfWeek, format: QtGui.QTextCharFormat
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#setWeekdayTextFormat

        **void QCalendarWidget::setWeekdayTextFormat(Qt::DayOfWeek dayOfWeek ,
        const QTextCharFormat & format )**

        Sets the text char format for rendering of day in the week **dayOfWeek**
        to **format**. The format will take precedence over the header format in
        case of foreground and background color. Other text formatting
        information is taken from the headers format.

        **See also** **weekdayTextFormat** () and **setHeaderTextFormat** ().
        """
        ...

    def weekdayTextFormat(
        self, dayOfWeek: QtCore.Qt.DayOfWeek
    ) -> QtGui.QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#weekdayTextFormat

        **QTextCharFormat QCalendarWidget::weekdayTextFormat(Qt::DayOfWeek
        dayOfWeek ) const**

        Returns the text char format for rendering of day in the week
        **dayOfWeek**.

        **See also** **setWeekdayTextFormat** () and **headerTextFormat** ().
        """
        ...

    def setHeaderTextFormat(self, format: QtGui.QTextCharFormat) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#setHeaderTextFormat

        **void QCalendarWidget::setHeaderTextFormat(const QTextCharFormat &
        format )**

        Sets the text char format for rendering the header to **format**. If you
        also set a weekday text format, this format's foreground and background
        color will take precedence over the header's format. The other
        formatting information will still be decided by the header's format.

        **See also** **headerTextFormat** ().
        """
        ...

    def headerTextFormat(self) -> QtGui.QTextCharFormat:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#headerTextFormat

        **QTextCharFormat QCalendarWidget::headerTextFormat() const**

        Returns the text char format for rendering the header.

        **See also** **setHeaderTextFormat** ().
        """
        ...

    def setVerticalHeaderFormat(
        self, format: "QCalendarWidget.VerticalHeaderFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#verticalHeaderFormat-prop

        **verticalHeaderFormat : VerticalHeaderFormat**

        This property holds the format of the vertical header.

        The default value is QCalendarWidget::ISOWeekNumber.

        **Access functions:**

        QCalendarWidget::VerticalHeaderFormat **verticalHeaderFormat** () const
        void **setVerticalHeaderFormat** (QCalendarWidget::VerticalHeaderFormat
        **format** )

        **Member Function Documentation**
        """
        ...

    def verticalHeaderFormat(self) -> "QCalendarWidget.VerticalHeaderFormat":
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#verticalHeaderFormat-prop

        **verticalHeaderFormat : VerticalHeaderFormat**

        This property holds the format of the vertical header.

        The default value is QCalendarWidget::ISOWeekNumber.

        **Access functions:**

        QCalendarWidget::VerticalHeaderFormat **verticalHeaderFormat** () const
        void **setVerticalHeaderFormat** (QCalendarWidget::VerticalHeaderFormat
        **format** )

        **Member Function Documentation**
        """
        ...

    def setHorizontalHeaderFormat(
        self, format: "QCalendarWidget.HorizontalHeaderFormat"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#horizontalHeaderFormat-prop

        **horizontalHeaderFormat : HorizontalHeaderFormat**

        This property holds the format of the horizontal header.

        The default value is **QCalendarWidget::ShortDayNames** .

        **Access functions:**

        QCalendarWidget::HorizontalHeaderFormat **horizontalHeaderFormat** ()
        const
        void **setHorizontalHeaderFormat**
        (QCalendarWidget::HorizontalHeaderFormat **format** )
        """
        ...

    def horizontalHeaderFormat(self) -> "QCalendarWidget.HorizontalHeaderFormat":
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#horizontalHeaderFormat-prop

        **horizontalHeaderFormat : HorizontalHeaderFormat**

        This property holds the format of the horizontal header.

        The default value is **QCalendarWidget::ShortDayNames** .

        **Access functions:**

        QCalendarWidget::HorizontalHeaderFormat **horizontalHeaderFormat** ()
        const
        void **setHorizontalHeaderFormat**
        (QCalendarWidget::HorizontalHeaderFormat **format** )
        """
        ...

    def setSelectionMode(self, mode: "QCalendarWidget.SelectionMode") -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#selectionMode-prop

        **selectionMode : SelectionMode**

        This property holds the type of selection the user can make in the
        calendar

        When this property is set to **SingleSelection** , the user can select a
        date within the minimum and maximum allowed dates, using either the
        mouse or the keyboard.

        When the property is set to **NoSelection** , the user will be unable to
        select dates, but they can still be selected programmatically. Note that
        the date that is selected when the property is set to **NoSelection**
        will still be the selected date of the calendar.

        The default value is **SingleSelection** .

        **Access functions:**

        QCalendarWidget::SelectionMode **selectionMode** () const
        void
        **setSelectionMode** (QCalendarWidget::SelectionMode **mode** )
        """
        ...

    def selectionMode(self) -> "QCalendarWidget.SelectionMode":
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#selectionMode-prop

        **selectionMode : SelectionMode**

        This property holds the type of selection the user can make in the
        calendar

        When this property is set to **SingleSelection** , the user can select a
        date within the minimum and maximum allowed dates, using either the
        mouse or the keyboard.

        When the property is set to **NoSelection** , the user will be unable to
        select dates, but they can still be selected programmatically. Note that
        the date that is selected when the property is set to **NoSelection**
        will still be the selected date of the calendar.

        The default value is **SingleSelection** .

        **Access functions:**

        QCalendarWidget::SelectionMode **selectionMode** () const
        void
        **setSelectionMode** (QCalendarWidget::SelectionMode **mode** )
        """
        ...

    def setGridVisible(self, show: bool) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#gridVisible-prop

        **gridVisible : bool**

        This property holds whether the table grid is displayed.

        ![](images/qcalendarwidget-grid.png)
        **QCalendarWidget**  *calendar;
            calendar->setGridVisible(true);

        The default value is false.

        **Access functions:**

        bool **isGridVisible** () const
        void **setGridVisible** (bool **show**
        )
        """
        ...

    def isGridVisible(self) -> bool:
        ...

    def setFirstDayOfWeek(self, dayOfWeek: QtCore.Qt.DayOfWeek) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#firstDayOfWeek-prop

        **firstDayOfWeek : Qt::DayOfWeek**

        This property holds a value identifying the day displayed in the first
        column.

        By default, the day displayed in the first column is the first day of
        the week for the calendar's locale.

        **Access functions:**

        Qt::DayOfWeek **firstDayOfWeek** () const
        void **setFirstDayOfWeek**
        (Qt::DayOfWeek **dayOfWeek** )
        """
        ...

    def firstDayOfWeek(self) -> QtCore.Qt.DayOfWeek:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#firstDayOfWeek-prop

        **firstDayOfWeek : Qt::DayOfWeek**

        This property holds a value identifying the day displayed in the first
        column.

        By default, the day displayed in the first column is the first day of
        the week for the calendar's locale.

        **Access functions:**

        Qt::DayOfWeek **firstDayOfWeek** () const
        void **setFirstDayOfWeek**
        (Qt::DayOfWeek **dayOfWeek** )
        """
        ...

    def setMaximumDate(self, date: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#maximumDate-prop

        **maximumDate : QDate**

        This property holds the maximum date of the currently specified date
        range.

        The user will not be able to select a date which is after the currently
        set maximum date.

        ![](images/qcalendarwidget-maximum.png)
        **QCalendarWidget**  *calendar;
            calendar->setGridVisible(true);
        calendar->setMaximumDate(**QDate** (2006, 7, 3));

        By default, the maximum date is the last day the **QDate**  class can
        handle.

        When setting a maximum date, the **minimumDate**  and **selectedDate**
        properties are adjusted if the selection range becomes invalid. If the
        provided date is not a valid **QDate**  object, the setMaximumDate()
        function does nothing.

        **Access functions:**

        QDate **maximumDate** () const
        void **setMaximumDate** (QDate **date**
        )

        **See also** **setDateRange** ().
        """
        ...

    def maximumDate(self) -> QtCore.QDate:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#maximumDate-prop

        **maximumDate : QDate**

        This property holds the maximum date of the currently specified date
        range.

        The user will not be able to select a date which is after the currently
        set maximum date.

        ![](images/qcalendarwidget-maximum.png)
        **QCalendarWidget**  *calendar;
            calendar->setGridVisible(true);
        calendar->setMaximumDate(**QDate** (2006, 7, 3));

        By default, the maximum date is the last day the **QDate**  class can
        handle.

        When setting a maximum date, the **minimumDate**  and **selectedDate**
        properties are adjusted if the selection range becomes invalid. If the
        provided date is not a valid **QDate**  object, the setMaximumDate()
        function does nothing.

        **Access functions:**

        QDate **maximumDate** () const
        void **setMaximumDate** (QDate **date**
        )

        **See also** **setDateRange** ().
        """
        ...

    def setMinimumDate(self, date: typing.Union[QtCore.QDate, datetime.date]) -> None:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#minimumDate-prop

        **minimumDate : QDate**

        This property holds the minimum date of the currently specified date
        range.

        The user will not be able to select a date that is before the currently
        set minimum date.

        ![](images/qcalendarwidget-minimum.png)
        **QCalendarWidget**  *calendar;
            calendar->setGridVisible(true);
        calendar->setMinimumDate(**QDate** (2006, 6, 19));

        By default, the minimum date is the earliest date that the **QDate**
        class can handle.

        When setting a minimum date, the **maximumDate**  and **selectedDate**
        properties are adjusted if the selection range becomes invalid. If the
        provided date is not a valid **QDate**  object, the setMinimumDate()
        function does nothing.

        **Access functions:**

        QDate **minimumDate** () const
        void **setMinimumDate** (QDate **date**
        )

        **See also** **setDateRange** ().
        """
        ...

    def minimumDate(self) -> QtCore.QDate:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#minimumDate-prop

        **minimumDate : QDate**

        This property holds the minimum date of the currently specified date
        range.

        The user will not be able to select a date that is before the currently
        set minimum date.

        ![](images/qcalendarwidget-minimum.png)
        **QCalendarWidget**  *calendar;
            calendar->setGridVisible(true);
        calendar->setMinimumDate(**QDate** (2006, 6, 19));

        By default, the minimum date is the earliest date that the **QDate**
        class can handle.

        When setting a minimum date, the **maximumDate**  and **selectedDate**
        properties are adjusted if the selection range becomes invalid. If the
        provided date is not a valid **QDate**  object, the setMinimumDate()
        function does nothing.

        **Access functions:**

        QDate **minimumDate** () const
        void **setMinimumDate** (QDate **date**
        )

        **See also** **setDateRange** ().
        """
        ...

    def monthShown(self) -> int:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#monthShown

        **int QCalendarWidget::monthShown() const**

        Returns the currently displayed month. Months are numbered from 1 to 12.

        **See also** **yearShown** () and **setCurrentPage** ().
        """
        ...

    def yearShown(self) -> int:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#yearShown

        **int QCalendarWidget::yearShown() const**

        Returns the year of the currently displayed month. Months are numbered
        from 1 to 12.

        **See also** **monthShown** () and **setCurrentPage** ().
        """
        ...

    def selectedDate(self) -> QtCore.QDate:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#selectedDate-prop

        **selectedDate : QDate**

        This property holds the currently selected date.

        The selected date must be within the date range specified by the
        **minimumDate**  and **maximumDate**  properties. By default, the
        selected date is the current date.

        **Access functions:**

        QDate **selectedDate** () const
        void **setSelectedDate** (QDate
        **date** )

        **See also** **setDateRange** ().
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#minimumSizeHint

        **[override virtual] QSize QCalendarWidget::minimumSizeHint() const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#sizeHint

        **[override virtual] QSize QCalendarWidget::sizeHint() const**

        Reimplements an access function for property: **QWidget::sizeHint** .
        """
        ...

    @property
    def activated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#activated

        **[signal] void QCalendarWidget::activated(QDate date )**

        This signal is emitted whenever the user presses the Return or Enter key
        or double-clicks a **date** in the calendar widget.
        """
        ...

    @property
    def clicked(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#clicked

        **[signal] void QCalendarWidget::clicked(QDate date )**

        This signal is emitted when a mouse button is clicked. The date the
        mouse was clicked on is specified by **date**. The signal is only
        emitted when clicked on a valid date, e.g., dates are not outside the
        **minimumDate** () and **maximumDate** (). If the selection mode is
        **NoSelection** , this signal will not be emitted.
        """
        ...

    @property
    def currentPageChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#currentPageChanged

        **[signal] void QCalendarWidget::currentPageChanged(int year , int month
        )**

        This signal is emitted when the currently shown month is changed. The
        new **year** and **month** are passed as parameters.

        **See also** **setCurrentPage** ().
        """
        ...

    @property
    def selectionChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qcalendarwidget.html#selectionChanged

        **[signal] void QCalendarWidget::selectionChanged()**

        This signal is emitted when the currently selected date is changed.

        The currently selected date can be changed by the user using the mouse
        or keyboard, or by the programmer using **setSelectedDate** ().

        **See also** **selectedDate** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtCore


class QPasswordDigestor(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpassworddigestor.html

    **Detailed Description**
    """

    def deriveKeyPbkdf2(
        self,
        algorithm: QtCore.QCryptographicHash.Algorithm,
        password: QtCore.QByteArray,
        salt: QtCore.QByteArray,
        iterations: int,
        dkLen: int,
    ) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qpassworddigestor.html#deriveKeyPbkdf2

        **[since 5.12] QByteArray
        QPasswordDigestor::deriveKeyPbkdf2(QCryptographicHash::Algorithm
        algorithm , const QByteArray & data , const QByteArray & salt , int
        iterations , quint64 dkLen )**

        Derive a key using the PBKDF2-algorithm as defined in **RFC 8018,
        section 5.2** .

        This function takes the **data** and **salt** , and then applies HMAC-X,
        where the X is **algorithm** , repeatedly. It internally concatenates
        intermediate results to the final output until at least **dkLen** amount
        of bytes have been computed and it will execute HMAC-X **iterations**
        times each time a concatenation is required. The total number of times
        it will execute HMAC-X depends on **iterations** , **dkLen** and
        **algorithm** and can be calculated as `iterations * ceil(dkLen /
        QCryptographicHash::hashLength(algorithm))`.

        This function was introduced in Qt 5.12.

        **See also** **deriveKeyPbkdf1** , **QMessageAuthenticationCode** , and
        **QCryptographicHash** .
        """
        ...

    def deriveKeyPbkdf1(
        self,
        algorithm: QtCore.QCryptographicHash.Algorithm,
        password: QtCore.QByteArray,
        salt: QtCore.QByteArray,
        iterations: int,
        dkLen: int,
    ) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qpassworddigestor.html#deriveKeyPbkdf1

        **[since 5.12] QByteArray
        QPasswordDigestor::deriveKeyPbkdf1(QCryptographicHash::Algorithm
        algorithm , const QByteArray & data , const QByteArray & salt , int
        iterations , quint64 dkLen )**

        Returns a hash computed using the PBKDF1-algorithm as defined in **RFC
        8018, section 5.1** .

        The function takes the **data** and **salt** , and then hashes it
        repeatedly for **iterations** iterations using the specified hash
        **algorithm**. If the resulting hash is longer than **dkLen** then it is
        truncated before it is returned.

        This function only supports SHA-1 and MD5! The max output size is 160
        bits (20 bytes) when using SHA-1, or 128 bits (16 bytes) when using MD5.
        Specifying a value for **dkLen** which is greater than this results in a
        warning and an empty **QByteArray**  is returned. To programmatically
        check this limit you can use **QCryptographicHash::hashLength** .
        Furthermore: the **salt** must always be 8 bytes long!

        **Note:** This function is provided for use with legacy applications and
        all new applications are recommended to use **PBKDF2** .

        This function was introduced in Qt 5.12.

        **See also** **deriveKeyPbkdf2** , **QCryptographicHash** , and
        **QCryptographicHash::hashLength** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6.QtCore import *
import enum


class QStringConverter(QStringConverterBase):
    """
    https://doc.qt.io/qt-6/qstringconverter.html

    **Detailed Description**

    Qt uses UTF-16 to store, draw and manipulate strings. In many situations you
    may wish to deal with data that uses a different encoding. Most text data
    transferred over files and network connections is encoded in UTF-8.

    The QStringConverter class is a base class for the **QStringEncoder**  and
    **QStringDecoder**  classes that help with converting between different text
    encodings. **QStringDecoder**  can decode a string from an encoded
    representation into UTF-16, the format Qt uses internally.
    **QStringEncoder**  does the opposite operation, encoding UTF-16 encoded
    data (usually in the form of a **QString** ) to the requested encoding.

    The supported encodings are:

    * UTF-8
      * UTF-16
      * UTF-16BE
      * UTF-16LE
      * UTF-32
      * UTF-32BE
      *
    UTF-32LE
      * ISO-8859-1 (Latin-1)
      * The system encoding

    **QStringConverter** s can be used as follows to convert some encoded string
    to and from UTF-16.

    Suppose you have some string encoded in UTF-8, and want to convert it to a
    **QString** . The simple way to do it is to use a **QStringDecoder**  like
    this:

    **QByteArray**  encodedString = "...";
        auto toUtf16 = **QStringDecoder**
    (**QStringDecoder** ::Utf8);
        **QString**  string =
    toUtf16(encodedString);

    After this, `string` holds the text in decoded form. Converting a string
    from Unicode to the local encoding is just as easy using the
    **QStringEncoder**  class:

    **QString**  string = "...";
        auto fromUtf16 = **QStringEncoder**
    (**QStringEncoder** ::Utf8);
        **QByteArray**  encodedString =
    fromUtf16(string);

    To read or write text files in various encodings, use **QTextStream**  and
    its **setEncoding** () function.

    Some care must be taken when trying to convert the data in chunks, for
    example, when receiving it over a network. In such cases it is possible that
    a multi-byte character will be split over two chunks. At best this might
    result in the loss of a character and at worst cause the entire conversion
    to fail.

    Both **QStringEncoder**  and **QStringDecoder**  make this easy, by tracking
    this in an internal state. So simply calling the encoder or decoder again
    with the next chunk of data will automatically continue encoding or decoding
    the data correctly:

    auto toUtf16 = **QStringDecoder** (**QStringDecoder** ::Utf8);
    **QString**  string;
        while (new_data_available()) {
    **QByteArray**  chunk = get_new_data();
            string += toUtf16(chunk);
    }

    The **QStringDecoder**  object maintains state between chunks and therefore
    works correctly even if a multi-byte character is split between chunks.

    QStringConverter objects can't be copied because of their internal state,
    but can be moved.

    **See also** **QTextStream** , **QStringDecoder** , and **QStringEncoder** .
    """

    class Encoding(enum.Enum):
        Utf8: QStringConverter = ...
        Utf16: QStringConverter = ...
        Utf16LE: QStringConverter = ...
        Utf16BE: QStringConverter = ...
        Utf32: QStringConverter = ...
        Utf32LE: QStringConverter = ...
        Utf32BE: QStringConverter = ...
        Latin1: QStringConverter = ...
        System: QStringConverter = ...

    @typing.overload
    def __init__(self) -> None:
        ...

    @typing.overload
    def __init__(
        self, encoding: "QStringConverter.Encoding", f: QStringConverterBase.Flag
    ) -> None:
        ...

    @typing.overload
    def __init__(self, name: str, f: QStringConverterBase.Flag) -> None:
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qstringconverter.html#name

        **const char *QStringConverter::name() const**

        Returns the canonical name of the encoding this **QStringConverter**
        can encode or decode. Returns a nullptr if the converter is not valid.

        **See also** **isValid** ().
        """
        ...

    def hasError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstringconverter.html#hasError

        **bool QStringConverter::hasError() const**

        Returns true if a conversion could not correctly convert a character.
        This could for example get triggered by an invalid UTF-8 sequence or
        when a character can't get converted due to limitations in the target
        encoding.
        """
        ...

    def resetState(self) -> None:
        """
        https://doc.qt.io/qt-6/qstringconverter.html#resetState

        **void QStringConverter::resetState()**

        Resets the internal state of the converter, clearing potential errors or
        partial conversions.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qstringconverter.html#isValid

        **bool QStringConverter::isValid() const**

        Returns true if this is a valid string converter that can be used for
        encoding or decoding text.

        Default constructed string converters or converters constructed with an
        unsupported name are not valid.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
import datetime
from PyQt6.QtWidgets import *


class QDateEdit(QDateTimeEdit):
    """
    https://doc.qt.io/qt-6/qdateedit.html

    **Detailed Description**

    ![](images/windows-dateedit.png)

    Many of the properties and functions provided by QDateEdit are implemented
    in **QDateTimeEdit** . These are the relevant properties of this class:

    * **date**  holds the date displayed by the widget.
      * **minimumDate**
    defines the minimum (earliest) date that can be set by the user.
      *
    **maximumDate**  defines the maximum (latest) date that can be set by the
    user.
      * **displayFormat**  contains a string that is used to format the
    date displayed in the widget.

    **See also** **QTimeEdit**  and **QDateTimeEdit** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdateedit.html#QDateEdit

        **QDateEdit::QDateEdit(QWidget * parent = nullptr)**

        Constructs an empty date editor with a **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        date: typing.Union[QtCore.QDate, datetime.date],
        parent: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdateedit.html#QDateEdit-1

        **QDateEdit::QDateEdit(QDate date , QWidget * parent = nullptr)**

        Constructs an empty date editor with a **parent**. The date is set to
        **date**.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNetwork import *
import enum


class QLocalServer(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qlocalserver.html

    **Detailed Description**

    This class makes it possible to accept incoming local socket connections.

    Call **listen** () to have the server start listening for incoming
    connections on a specified key. The **newConnection** () signal is then
    emitted each time a client connects to the server.

    Call **nextPendingConnection** () to accept the pending connection as a
    connected **QLocalSocket** . The function returns a pointer to a
    **QLocalSocket**  that can be used for communicating with the client.

    If an error occurs, **serverError** () returns the type of error, and
    **errorString** () can be called to get a human readable description of what
    happened.

    When listening for connections, the name which the server is listening on is
    available through **serverName** ().

    Calling **close** () makes QLocalServer stop listening for incoming
    connections.

    Although QLocalServer is designed for use with an event loop, it's possible
    to use it without one. In that case, you must use **waitForNewConnection**
    (), which blocks until either a connection is available or a timeout
    expires.

    **See also** **QLocalSocket**  and **QTcpServer** .
    """

    class SocketOption(enum.Flag):
        UserAccessOption: QLocalServer = ...
        GroupAccessOption: QLocalServer = ...
        OtherAccessOption: QLocalServer = ...
        WorldAccessOption: QLocalServer = ...
        AbstractNamespaceOption: QLocalServer = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#QLocalServer

        **QLocalServer::QLocalServer(QObject * parent = nullptr)**

        Create a new local socket server with the given **parent**.

        **See also** **listen** ().
        """
        ...

    def socketDescriptor(self) -> PyQt6.sip.voidptr:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#socketDescriptor

        **[since 5.10] qintptr QLocalServer::socketDescriptor() const**

        Returns the native socket descriptor the server uses to listen for
        incoming instructions, or -1 if the server is not listening.

        The type of the descriptor depends on the platform:

        * On Windows, the returned value is a **Winsock 2 Socket Handle** .
          *
        On INTEGRITY, the returned value is the **QTcpServer**  socket
        descriptor and the type is defined by **socketDescriptor** .
          * On all
        other UNIX-like operating systems, the type is a file descriptor
        representing a listening socket.

        This function was introduced in Qt 5.10.

        **See also** **listen** ().
        """
        ...

    def socketOptions(self) -> "QLocalServer.SocketOption":
        """
        https://doc.qt.io/qt-6/qlocalserver.html#socketOptions

        **[since 5.0] QLocalServer::SocketOptions QLocalServer::socketOptions()
        const**

        Returns the socket options set on the socket.

        **Note:** Getter function for property socketOptions.

        This function was introduced in Qt 5.0.

        **See also** **setSocketOptions** ().
        """
        ...

    def setSocketOptions(self, options: "QLocalServer.SocketOption") -> None:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#socketOptions-prop

        **[bindable, since 5.0] socketOptions : SocketOptions**

        **Note:** This property supports **QProperty**  bindings.

        This property holds the socket options that control how the socket
        operates.

        For example, the socket may restrict access to what user ids can connect
        to the socket.

        These options must be set before **listen** () is called.

        In some cases, such as with Unix domain sockets on Linux, the access to
        the socket will be determined by file system permissions, and are
        created based on the umask. Setting the access flags will override this
        and will restrict or permit access as specified.

        Other Unix-based operating systems, such as macOS, do not honor file
        permissions for Unix domain sockets and by default have WorldAccess and
        these permission flags will have no effect.

        On Windows, **UserAccessOption**  is sufficient to allow a non elevated
        process to connect to a local server created by an elevated process run
        by the same user. **GroupAccessOption**  refers to the primary group of
        the process (see TokenPrimaryGroup in the Windows documentation).
        **OtherAccessOption**  refers to the well known "Everyone" group.

        On Linux platforms it is possible to create a socket in the abstract
        namespace, which is independent of the filesystem. Using this kind of
        socket implies ignoring permission options. On other platforms
        **AbstractNamespaceOption**  is equivalent to **WorldAccessOption** .

        By default none of the flags are set, access permissions are the
        platform default.

        This property was introduced in Qt 5.0.

        **See also** **listen** ().

        **Member Function Documentation**
        """
        ...

    def incomingConnection(self, socketDescriptor: PyQt6.sip.voidptr) -> None:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#incomingConnection

        **[virtual protected] void QLocalServer::incomingConnection(quintptr
        socketDescriptor )**

        This virtual function is called by **QLocalServer**  when a new
        connection is available. **socketDescriptor** is the native socket
        descriptor for the accepted connection.

        The base implementation creates a **QLocalSocket** , sets the socket
        descriptor and then stores the **QLocalSocket**  in an internal list of
        pending connections. Finally **newConnection** () is emitted.

        Reimplement this function to alter the server's behavior when a
        connection is available.

        **See also** **newConnection** (), **nextPendingConnection** (), and
        **QLocalSocket::setSocketDescriptor** ().
        """
        ...

    @staticmethod
    def removeServer(name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#removeServer

        **[static] bool QLocalServer::removeServer(const QString & name )**

        Removes any server instance that might cause a call to **listen** () to
        fail and returns `true` if successful; otherwise returns `false`. This
        function is meant to recover from a crash, when the previous server
        instance has not been cleaned up.

        On Windows, this function does nothing; on Unix, it removes the socket
        file given by **name**.

        **Warning:** Be careful to avoid removing sockets of running instances.
        """
        ...

    def waitForNewConnection(self, msecs: int = ...) -> typing.Tuple[bool, bool]:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#waitForNewConnection

        **bool QLocalServer::waitForNewConnection(int msec = 0, bool * timedOut
        = nullptr)**

        Waits for at most **msec** milliseconds or until an incoming connection
        is available. Returns `true` if a connection is available; otherwise
        returns `false`. If the operation timed out and **timedOut** is not
        `nullptr`, *timedOut will be set to true.

        This is a blocking function call. Its use is ill-advised in a single-
        threaded GUI application, since the whole application will stop
        responding until the function returns. waitForNewConnection() is mostly
        useful when there is no event loop available.

        The non-blocking alternative is to connect to the **newConnection** ()
        signal.

        If msec is -1, this function will not time out.

        **See also** **hasPendingConnections** () and **nextPendingConnection**
        ().
        """
        ...

    def setMaxPendingConnections(self, numConnections: int) -> None:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#setMaxPendingConnections

        **void QLocalServer::setMaxPendingConnections(int numConnections )**

        Sets the maximum number of pending accepted connections to
        **numConnections**. **QLocalServer**  will accept no more than
        **numConnections** incoming connections before **nextPendingConnection**
        () is called.

        Note: Even though **QLocalServer**  will stop accepting new connections
        after it has reached its maximum number of pending connections, the
        operating system may still keep them in queue which will result in
        clients signaling that it is connected.

        **See also** **maxPendingConnections** () and **hasPendingConnections**
        ().
        """
        ...

    def serverError(self) -> QAbstractSocket.SocketError:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#serverError

        **QAbstractSocket::SocketError QLocalServer::serverError() const**

        Returns the type of error that occurred last or **NoError** .

        **See also** **errorString** ().
        """
        ...

    def fullServerName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#fullServerName

        **QString QLocalServer::fullServerName() const**

        Returns the full path that the server is listening on.

        Note: This is platform specific

        **See also** **listen** () and **serverName** ().
        """
        ...

    def serverName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#serverName

        **QString QLocalServer::serverName() const**

        Returns the server name if the server is listening for connections;
        otherwise returns QString()

        **See also** **listen** () and **fullServerName** ().
        """
        ...

    def nextPendingConnection(self) -> "QLocalSocket":
        """
        https://doc.qt.io/qt-6/qlocalserver.html#nextPendingConnection

        **[virtual] QLocalSocket *QLocalServer::nextPendingConnection()**

        Returns the next pending connection as a connected **QLocalSocket**
        object.

        The socket is created as a child of the server, which means that it is
        automatically deleted when the **QLocalServer**  object is destroyed. It
        is still a good idea to delete the object explicitly when you are done
        with it, to avoid wasting memory.

        `nullptr` is returned if this function is called when there are no
        pending connections.

        **See also** **hasPendingConnections** (), **newConnection** (), and
        **incomingConnection** ().
        """
        ...

    def maxPendingConnections(self) -> int:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#maxPendingConnections

        **int QLocalServer::maxPendingConnections() const**

        Returns the maximum number of pending accepted connections. The default
        is 30.

        **See also** **setMaxPendingConnections** () and
        **hasPendingConnections** ().
        """
        ...

    @typing.overload
    def listen(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#listen

        **bool QLocalServer::listen(const QString & name )**

        Tells the server to listen for incoming connections on **name**. If the
        server is currently listening then it will return false. Return true on
        success otherwise false.

        **name** can be a single name and **QLocalServer**  will determine the
        correct platform specific path. **serverName** () will return the name
        that is passed into listen.

        Usually you would just pass in a name like "foo", but on Unix this could
        also be a path such as "/tmp/foo" and on Windows this could be a pipe
        path such as "\\\\\\\\.\\pipe\\foo"

        **Note:** On Unix if the server crashes without closing listen will fail
        with AddressInUseError. To create a new server the file should be
        removed. On Windows two local servers can listen to the same pipe at the
        same time, but any connections will go to one of the server.

        **See also** **serverName** (), **isListening** (), and **close** ().
        """
        ...

    @typing.overload
    def listen(self, socketDescriptor: PyQt6.sip.voidptr) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#listen-1

        **[since 5.0] bool QLocalServer::listen(qintptr socketDescriptor )**

        Instructs the server to listen for incoming connections on
        **socketDescriptor**. The property returns `false` if the server is
        currently listening. It returns `true` on success; otherwise, it returns
        `false`. The socket must be ready to accept new connections with no
        extra platform-specific functions called. The socket is set into non-
        blocking mode.

        **serverName** (), **fullServerName** () may return a string with a name
        if this option is supported by the platform; otherwise, they return an
        empty **QString** . In particular, the addresses of sockets in the
        abstract namespace supported by Linux will not yield useful names if
        they contain unprintable characters.

        This function was introduced in Qt 5.0.

        **See also** **isListening** () and **close** ().
        """
        ...

    def isListening(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#isListening

        **bool QLocalServer::isListening() const**

        Returns `true` if the server is listening for incoming connections
        otherwise false.

        **See also** **listen** () and **close** ().
        """
        ...

    def hasPendingConnections(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#hasPendingConnections

        **[virtual] bool QLocalServer::hasPendingConnections() const**

        Returns `true` if the server has a pending connection; otherwise returns
        `false`.

        **See also** **nextPendingConnection** () and
        **setMaxPendingConnections** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#errorString

        **QString QLocalServer::errorString() const**

        Returns the human-readable message appropriate to the current error
        reported by **serverError** (). If no suitable string is available, an
        empty string is returned.

        **See also** **serverError** ().
        """
        ...

    def close(self) -> None:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#close

        **void QLocalServer::close()**

        Stop listening for incoming connections. Existing connections are not
        affected, but any new connections will be refused.

        **See also** **isListening** () and **listen** ().
        """
        ...

    @property
    def newConnection(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qlocalserver.html#newConnection

        **[signal] void QLocalServer::newConnection()**

        This signal is emitted every time a new connection is available.

        **See also** **hasPendingConnections** () and **nextPendingConnection**
        ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtNfc import *
import enum


class QNearFieldTarget(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qnearfieldtarget.html

    **Detailed Description**

    QNearFieldTarget provides a generic interface for communicating with an NFC
    target device. Both NFC Forum devices and NFC Forum Tag targets are
    supported by this class. All target specific classes subclass this class.

    The **type** () function can be used to get the type of the target device.
    The **uid** () function returns the unique identifier of the target. The
    **AccessMethods**  flags returns from the **accessMethods** () function can
    be tested to determine which access methods are supported by the target.

    If the target supports **NdefAccess** , **hasNdefMessage** () can be called
    to test if the target has a stored NDEF message, **readNdefMessages** () and
    **writeNdefMessages** () functions can be used to get and set the NDEF
    message.

    If the target supports **TagTypeSpecificAccess** , **sendCommand** () can be
    used to send a single proprietary command to the target and retrieve the
    response.
    """

    class Error(enum.Enum):
        NoError: QNearFieldTarget = ...
        UnknownError: QNearFieldTarget = ...
        UnsupportedError: QNearFieldTarget = ...
        TargetOutOfRangeError: QNearFieldTarget = ...
        NoResponseError: QNearFieldTarget = ...
        ChecksumMismatchError: QNearFieldTarget = ...
        InvalidParametersError: QNearFieldTarget = ...
        NdefReadError: QNearFieldTarget = ...
        NdefWriteError: QNearFieldTarget = ...
        CommandError: QNearFieldTarget = ...
        ConnectionError: QNearFieldTarget = ...
        TimeoutError: QNearFieldTarget = ...

    class AccessMethod(enum.Flag):
        UnknownAccess: QNearFieldTarget = ...
        NdefAccess: QNearFieldTarget = ...
        TagTypeSpecificAccess: QNearFieldTarget = ...
        AnyAccess: QNearFieldTarget = ...

    class Type(enum.Enum):
        ProprietaryTag: QNearFieldTarget = ...
        NfcTagType1: QNearFieldTarget = ...
        NfcTagType2: QNearFieldTarget = ...
        NfcTagType3: QNearFieldTarget = ...
        NfcTagType4: QNearFieldTarget = ...
        NfcTagType4A: QNearFieldTarget = ...
        NfcTagType4B: QNearFieldTarget = ...
        MifareTag: QNearFieldTarget = ...

    class RequestId(PyQt6.sip.simplewrapper):
        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, other: "QNearFieldTarget.RequestId") -> None:
            ...

        def refCount(self) -> int:
            ...

        def isValid(self) -> bool:
            ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#QNearFieldTarget

        **QNearFieldTarget::QNearFieldTarget(QObject * parent = nullptr)**

        Constructs a new near field target with **parent**.
        """
        ...

    def maxCommandLength(self) -> int:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#maxCommandLength

        **[since 5.9] int QNearFieldTarget::maxCommandLength() const**

        Returns the maximum number of bytes that can be sent with
        **sendCommand** . 0 will be returned if the target does not support
        sending tag type specific commands.

        This function was introduced in Qt 5.9.

        **See also** **sendCommand** ().
        """
        ...

    def disconnect(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#disconnect

        **[since 5.9] bool QNearFieldTarget::disconnect()**

        Closes the connection to the target to enable communication with the
        target from a different instance. The connection will also be closed,
        when the **QNearFieldTarget**  is destroyed. A connection to the target
        device is (re)created to process a command or read/write a NDEF
        messages.

        Returns `true` only if an existing connection was successfully closed;
        otherwise returns `false`.

        This function was introduced in Qt 5.9.
        """
        ...

    def requestResponse(self, id: "QNearFieldTarget.RequestId") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#requestResponse

        **QVariant QNearFieldTarget::requestResponse(const
        QNearFieldTarget::RequestId & id ) const**

        Returns the decoded response for request **id**. If the request is
        unknown or has not yet been completed an invalid **QVariant**  is
        returned.
        """
        ...

    def waitForRequestCompleted(
        self, id: "QNearFieldTarget.RequestId", msecs: int = ...
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#waitForRequestCompleted

        **bool QNearFieldTarget::waitForRequestCompleted(const
        QNearFieldTarget::RequestId & id , int msecs = 5000)**

        Waits up to **msecs** milliseconds for the request **id** to complete.
        Returns `true` if the request completes successfully and the
        requestCompeted() signal is emitted; otherwise returns `false`.
        """
        ...

    def sendCommand(self, command: QtCore.QByteArray) -> "QNearFieldTarget.RequestId":
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#sendCommand

        **QNearFieldTarget::RequestId QNearFieldTarget::sendCommand(const
        QByteArray & command )**

        Sends **command** to the near field target. Returns a request id which
        can be used to track the completion status of the request. An invalid
        request id will be returned if the target does not support sending tag
        type specific commands.

        The **requestCompleted** () signal will be emitted on successful
        completion of the request; otherwise the **error** () signal will be
        emitted.

        Once the request completes successfully the response can be retrieved
        from the **requestResponse** () function. The response of this request
        will be a **QByteArray** .

        **See also** **requestCompleted** () and **waitForRequestCompleted** ().
        """
        ...

    def writeNdefMessages(
        self, messages: typing.Iterable[QNdefMessage]
    ) -> "QNearFieldTarget.RequestId":
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#writeNdefMessages

        **QNearFieldTarget::RequestId QNearFieldTarget::writeNdefMessages(const
        QList<QNdefMessage> & messages )**

        Writes the NDEF messages in **messages** to the target. Returns a
        request id which can be used to track the completion status of the
        request. An invalid request id will be returned if the target does not
        support reading NDEF messages.

        The **requestCompleted** () signal will be emitted when the write
        operation completes successfully; otherwise the **error** () signal is
        emitted.
        """
        ...

    def readNdefMessages(self) -> "QNearFieldTarget.RequestId":
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#readNdefMessages

        **QNearFieldTarget::RequestId QNearFieldTarget::readNdefMessages()**

        Starts reading NDEF messages stored on the near field target. Returns a
        request id which can be used to track the completion status of the
        request. An invalid request id will be returned if the target does not
        support reading NDEF messages.

        An **ndefMessageRead** () signal will be emitted for each NDEF message.
        The **requestCompleted** () signal will be emitted was all NDEF messages
        have been read. The **error** () signal is emitted if an error occurs.

        **Note:** An attempt to read an NDEF message from a tag, that is in
        INITIALIZED state as defined by NFC Forum, will fail with the
        **NdefReadError** , as the tag is formatted to support NDEF but does not
        contain a message yet.
        """
        ...

    def hasNdefMessage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#hasNdefMessage

        **bool QNearFieldTarget::hasNdefMessage()**

        Returns `true` if at least one NDEF message is stored on the near field
        target; otherwise returns `false`.
        """
        ...

    def accessMethods(self) -> "QNearFieldTarget.AccessMethod":
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#accessMethods

        **QNearFieldTarget::AccessMethods QNearFieldTarget::accessMethods()
        const**

        Returns the access methods support by this near field target.
        """
        ...

    def type(self) -> "QNearFieldTarget.Type":
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#type

        **QNearFieldTarget::Type QNearFieldTarget::type() const**

        Returns the type of tag type of this near field target.
        """
        ...

    def uid(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#uid

        **QByteArray QNearFieldTarget::uid() const**

        Returns the UID of the near field target.
        """
        ...

    @property
    def disconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#disconnected

        **[signal] void QNearFieldTarget::disconnected()**

        This signal is emitted when the near field target moves out of
        proximity.
        """
        ...

    @property
    def error(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#error

        **[signal] void QNearFieldTarget::error(QNearFieldTarget::Error error ,
        const QNearFieldTarget::RequestId & id )**

        This signal is emitted when an error occurs while processing request
        **id**. The **error** parameter describes the error.
        """
        ...

    @property
    def ndefMessageRead(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#ndefMessageRead

        **[signal] void QNearFieldTarget::ndefMessageRead(const QNdefMessage &
        message )**

        This signal is emitted when a complete NDEF **message** has been read
        from the target.

        **See also** **readNdefMessages** ().
        """
        ...

    @property
    def requestCompleted(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qnearfieldtarget.html#requestCompleted

        **[signal] void QNearFieldTarget::requestCompleted(const
        QNearFieldTarget::RequestId & id )**

        This signal is emitted when a request **id** completes.

        **See also** **sendCommand** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtGui import *
import enum


class QFont(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qfont.html

    **Detailed Description**

    QFont can be regarded as a query for one or more fonts on the system.

    When you create a QFont object you specify various attributes that you want
    the font to have. Qt will use the font with the specified attributes, or if
    no matching font exists, Qt will use the closest matching installed font.
    The attributes of the font that is actually used are retrievable from a
    **QFontInfo**  object. If the window system provides an exact match
    **exactMatch** () returns `true`. Use **QFontMetricsF**  to get
    measurements, e.g. the pixel length of a string using QFontMetrics::width().

    Attributes which are not specifically set will not affect the font selection
    algorithm, and default values will be preferred instead.

    To load a specific physical font, typically represented by a single file,
    use **QRawFont**  instead.

    Note that a **QGuiApplication**  instance must exist before a QFont can be
    used. You can set the application's default font with
    **QGuiApplication::setFont** ().

    If a chosen font does not include all the characters that need to be
    displayed, QFont will try to find the characters in the nearest equivalent
    fonts. When a **QPainter**  draws a character from a font the QFont will
    report whether or not it has the character; if it does not, **QPainter**
    will draw an unfilled square.

    Create QFonts like this:

    **QFont**  serifFont("Times", 10, **QFont** ::Bold);
        **QFont**
    sansFont("Helvetica [Cronyx]", 12);

    The attributes set in the constructor can also be set later, e.g.
    **setFamily** (), **setPointSize** (), **setPointSizeF** (), **setWeight**
    () and **setItalic** (). The remaining attributes must be set after
    construction, e.g. **setBold** (), **setUnderline** (), **setOverline** (),
    **setStrikeOut** () and **setFixedPitch** (). **QFontInfo**  objects should
    be created **after** the font's attributes have been set. A **QFontInfo**
    object will not change, even if you change the font's attributes. The
    corresponding "get" functions, e.g. **family** (), **pointSize** (), etc.,
    return the values that were set, even though the values used may differ. The
    actual values are available from a **QFontInfo**  object.

    If the requested font family is unavailable you can influence the **font
    matching algorithm**  by choosing a particular **QFont::StyleHint**  and
    **QFont::StyleStrategy**  with **setStyleHint** (). The default family
    (corresponding to the current style hint) is returned by **defaultFamily**
    ().

    You can provide substitutions for font family names using
    **insertSubstitution** () and **insertSubstitutions** (). Substitutions can
    be removed with **removeSubstitutions** (). Use **substitute** () to
    retrieve a family's first substitute, or the family name itself if it has no
    substitutes. Use **substitutes** () to retrieve a list of a family's
    substitutes (which may be empty). After substituting a font, you must
    trigger the updating of the font by destroying and re-creating all QFont
    objects.

    Every QFont has a **key** () which you can use, for example, as the key in a
    cache or dictionary. If you want to store a user's font preferences you
    could use **QSettings** , writing the font information with **toString** ()
    and reading it back with **fromString** (). The operator<<() and
    operator>>() functions are also available, but they work on a data stream.

    It is possible to set the height of characters shown on the screen to a
    specified number of pixels with **setPixelSize** (); however using
    **setPointSize** () has a similar effect and provides device independence.

    Loading fonts can be expensive, especially on X11. QFont contains extensive
    optimizations to make the copying of QFont objects fast, and to cache the
    results of the slow window system functions it depends upon.

    The font matching algorithm works as follows:

    1. The specified font families (set by **setFamilies** ()) are searched for.
    2. If not found, then if set the specified font family exists and can be
    used to represent the writing system in use, it will be selected.
      3. If
    not, a replacement font that supports the writing system is selected. The
    font matching algorithm will try to find the best match for all the
    properties set in the QFont. How this is done varies from platform to
    platform.
      4. If no font exists on the system that can support the text,
    then special "missing character" boxes will be shown in its place.

    **Note:** If the selected font, though supporting the writing system in
    general, is missing glyphs for one or more specific characters, then Qt will
    try to find a fallback font for this or these particular characters. This
    feature can be disabled using **QFont::NoFontMerging**  style strategy.

    In Windows a request for the "Courier" font is automatically changed to
    "Courier New", an improved version of Courier that allows for smooth
    scaling. The older "Courier" bitmap font can be selected by setting the
    **PreferBitmap**  style strategy (see **setStyleStrategy** ()).

    Once a font is found, the remaining attributes are matched in order of
    priority:

    1. **fixedPitch** ()
      2. **pointSize** () (see below)
      3. **weight** ()
    4. **style** ()

    If you have a font which matches on family, even if none of the other
    attributes match, this font will be chosen in preference to a font which
    doesn't match on family but which does match on the other attributes. This
    is because font family is the dominant search criteria.

    The point size is defined to match if it is within 20% of the requested
    point size. When several fonts match and are only distinguished by point
    size, the font with the closest point size to the one requested will be
    chosen.

    The actual family, font size, weight and other font attributes used for
    drawing text will depend on what's available for the chosen family under the
    window system. A **QFontInfo**  object can be used to determine the actual
    values used for drawing the text.

    Examples:

    **QFont**  f("Helvetica");

    If you had both an Adobe and a Cronyx Helvetica, you might get either.

    **QFont**  f("Helvetica [Cronyx]");

    You can specify the foundry you want in the family name. The font f in the
    above example will be set to "Helvetica [Cronyx]".

    To determine the attributes of the font actually used in the window system,
    use a **QFontInfo**  object, e.g.

    **QFontInfo**  info(f1);
        **QString**  family = info.family();

    To find out font metrics use a **QFontMetrics**  object, e.g.

    **QFontMetrics**  fm(f1);
        int textWidthInPixels =
    fm.horizontalAdvance("How many pixels wide is this text?");
        int
    textHeightInPixels = fm.height();

    For more general information on fonts, see the **comp.fonts FAQ** .
    Information on encodings can be found from the **UTR17**  page.

    **See also** **QFontMetrics** , **QFontInfo** , **QFontDatabase** , and
    **Character Map Example** .
    """

    class HintingPreference(enum.Enum):
        PreferDefaultHinting: QFont = ...
        PreferNoHinting: QFont = ...
        PreferVerticalHinting: QFont = ...
        PreferFullHinting: QFont = ...

    class SpacingType(enum.Enum):
        PercentageSpacing: QFont = ...
        AbsoluteSpacing: QFont = ...

    class Capitalization(enum.Enum):
        MixedCase: QFont = ...
        AllUppercase: QFont = ...
        AllLowercase: QFont = ...
        SmallCaps: QFont = ...
        Capitalize: QFont = ...

    class Stretch(enum.Enum):
        AnyStretch: QFont = ...
        UltraCondensed: QFont = ...
        ExtraCondensed: QFont = ...
        Condensed: QFont = ...
        SemiCondensed: QFont = ...
        Unstretched: QFont = ...
        SemiExpanded: QFont = ...
        Expanded: QFont = ...
        ExtraExpanded: QFont = ...
        UltraExpanded: QFont = ...

    class Style(enum.Enum):
        StyleNormal: QFont = ...
        StyleItalic: QFont = ...
        StyleOblique: QFont = ...

    class Weight(enum.IntEnum):
        Thin: QFont = ...
        ExtraLight: QFont = ...
        Light: QFont = ...
        Normal: QFont = ...
        Medium: QFont = ...
        DemiBold: QFont = ...
        Bold: QFont = ...
        ExtraBold: QFont = ...
        Black: QFont = ...

    class StyleStrategy(enum.Flag):
        PreferDefault: QFont = ...
        PreferBitmap: QFont = ...
        PreferDevice: QFont = ...
        PreferOutline: QFont = ...
        ForceOutline: QFont = ...
        PreferMatch: QFont = ...
        PreferQuality: QFont = ...
        PreferAntialias: QFont = ...
        NoAntialias: QFont = ...
        NoSubpixelAntialias: QFont = ...
        NoFontMerging: QFont = ...
        PreferNoShaping: QFont = ...

    class StyleHint(enum.Enum):
        Helvetica: QFont = ...
        SansSerif: QFont = ...
        Times: QFont = ...
        Serif: QFont = ...
        Courier: QFont = ...
        TypeWriter: QFont = ...
        OldEnglish: QFont = ...
        Decorative: QFont = ...
        System: QFont = ...
        AnyStyle: QFont = ...
        Cursive: QFont = ...
        Monospace: QFont = ...
        Fantasy: QFont = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#QFont

        **QFont::QFont()**

        Constructs a font object that uses the application's default font.

        **See also** **QGuiApplication::setFont** () and
        **QGuiApplication::font** ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        families: typing.Iterable[str],
        pointSize: int = ...,
        weight: int = ...,
        italic: bool = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#QFont-1

        **QFont::QFont(const QString & family , int pointSize = -1, int weight =
        -1, bool italic = false)**

        Constructs a font object with the specified **family** , **pointSize** ,
        **weight** and **italic** settings.

        If **pointSize** is zero or negative, the point size of the font is set
        to a system-dependent default value. Generally, this is 12 points.

        The **family** name may optionally also include a foundry name, e.g.
        "Helvetica [Cronyx]". If the **family** is available from more than one
        foundry and the foundry isn't specified, an arbitrary foundry is chosen.
        If the family isn't available a family will be set using the **font
        matching**  algorithm.

        This will split the family string on a comma and call **setFamilies** ()
        with the resulting list. To preserve a font that uses a comma in its
        name, use the constructor that takes a **QStringList** .

        **See also** **Weight** , **setFamily** (), **setPointSize** (),
        **setWeight** (), **setItalic** (), **setStyleHint** (), **setFamilies**
        (), and **QGuiApplication::font** ().
        """
        ...

    @typing.overload
    def __init__(
        self, family: str, pointSize: int = ..., weight: int = ..., italic: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#QFont-2

        **QFont::QFont(const QStringList & families , int pointSize = -1, int
        weight = -1, bool italic = false)**

        Constructs a font object with the specified **families** , **pointSize**
        , **weight** and **italic** settings.

        If **pointSize** is zero or negative, the point size of the font is set
        to a system-dependent default value. Generally, this is 12 points.

        Each family name entry in **families** may optionally also include a
        foundry name, e.g. "Helvetica [Cronyx]". If the family is available from
        more than one foundry and the foundry isn't specified, an arbitrary
        foundry is chosen. If the family isn't available a family will be set
        using the **font matching**  algorithm.

        **See also** **Weight** , **setPointSize** (), **setWeight** (),
        **setItalic** (), **setStyleHint** (), **setFamilies** (), and
        **QGuiApplication::font** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QFont") -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#QFont-3

        **[since 5.13] QFont::QFont(const QFont & font , const QPaintDevice * pd
        )**

        Constructs a font from **font** for use on the paint device **pd**.

        This function was introduced in Qt 5.13.
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#QFont-4

        **QFont::QFont(const QFont & font )**

        Constructs a font that is a copy of **font**.
        """
        ...

    def setFamilies(self, a0: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setFamilies

        **[since 5.13] void QFont::setFamilies(const QStringList & families )**

        Sets the list of family names for the font. The names are case
        insensitive and may include a foundry name. The first family in
        **families** will be set as the main family for the font.

        Each family name entry in **families** may optionally also include a
        foundry name, e.g. "Helvetica [Cronyx]". If the family is available from
        more than one foundry and the foundry isn't specified, an arbitrary
        foundry is chosen. If the family isn't available a family will be set
        using the **font matching**  algorithm.

        This function was introduced in Qt 5.13.

        **See also** **family** (), **families** (), **setFamily** (),
        **setStyleHint** (), and **QFontInfo** .
        """
        ...

    def families(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfont.html#families

        **[since 5.13] QStringList QFont::families() const**

        Returns the requested font family names, i.e. the names set in the last
        **setFamilies** () call or via the constructor. Otherwise it returns an
        empty list.

        This function was introduced in Qt 5.13.

        **See also** **setFamily** (), **setFamilies** (), **family** (),
        **substitutes** (), and **substitute** ().
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QFont") -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#swap

        **[since 5.0] void QFont::swap(QFont & other )**

        Swaps this font instance with **other**. This function is very fast and
        never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def hintingPreference(self) -> "QFont.HintingPreference":
        """
        https://doc.qt.io/qt-6/qfont.html#hintingPreference

        **QFont::HintingPreference QFont::hintingPreference() const**

        Returns the currently preferred hinting level for glyphs rendered with
        this font.

        **See also** **setHintingPreference** ().
        """
        ...

    def setHintingPreference(
        self, hintingPreference: "QFont.HintingPreference"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setHintingPreference

        **void QFont::setHintingPreference(QFont::HintingPreference
        hintingPreference )**

        Set the preference for the hinting level of the glyphs to
        **hintingPreference**. This is a hint to the underlying font rendering
        system to use a certain level of hinting, and has varying support across
        platforms. See the table in the documentation for
        **QFont::HintingPreference**  for more details.

        The default hinting preference is **QFont::PreferDefaultHinting** .

        **See also** **hintingPreference** ().
        """
        ...

    def setStyleName(self, styleName: str) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setStyleName

        **void QFont::setStyleName(const QString & styleName )**

        Sets the style name of the font to **styleName**. When set, other style
        properties like **style** () and **weight** () will be ignored for font
        matching, though they may be simulated afterwards if supported by the
        platform's font engine.

        Due to the lower quality of artificially simulated styles, and the lack
        of full cross platform support, it is not recommended to use matching by
        style name together with matching by style properties

        **See also** **styleName** ().
        """
        ...

    def styleName(self) -> str:
        """
        https://doc.qt.io/qt-6/qfont.html#styleName

        **QString QFont::styleName() const**

        Returns the requested font style name. This can be used to match the
        font with irregular styles (that can't be normalized in other style
        properties).

        **See also** **setStyleName** (), **setFamily** (), and **setStyle** ().
        """
        ...

    def capitalization(self) -> "QFont.Capitalization":
        """
        https://doc.qt.io/qt-6/qfont.html#capitalization

        **QFont::Capitalization QFont::capitalization() const**

        Returns the current capitalization type of the font.

        **See also** **setCapitalization** ().
        """
        ...

    def setCapitalization(self, a0: "QFont.Capitalization") -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setCapitalization

        **void QFont::setCapitalization(QFont::Capitalization caps )**

        Sets the capitalization of the text in this font to **caps**.

        A font's capitalization makes the text appear in the selected
        capitalization mode.

        **See also** **capitalization** ().
        """
        ...

    def setWordSpacing(self, spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setWordSpacing

        **void QFont::setWordSpacing(qreal spacing )**

        Sets the word spacing for the font to **spacing**.

        Word spacing changes the default spacing between individual words. A
        positive value increases the word spacing by a corresponding amount of
        pixels, while a negative value decreases the inter-word spacing
        accordingly.

        Word spacing will not apply to writing systems, where indiviaul words
        are not separated by white space.

        **See also** **wordSpacing** () and **setLetterSpacing** ().
        """
        ...

    def wordSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qfont.html#wordSpacing

        **qreal QFont::wordSpacing() const**

        Returns the word spacing for the font.

        **See also** **setWordSpacing** () and **setLetterSpacing** ().
        """
        ...

    def setLetterSpacing(self, type: "QFont.SpacingType", spacing: float) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setLetterSpacing

        **void QFont::setLetterSpacing(QFont::SpacingType type , qreal spacing
        )**

        Sets the letter spacing for the font to **spacing** and the type of
        spacing to **type**.

        Letter spacing changes the default spacing between individual letters in
        the font. The spacing between the letters can be made smaller as well as
        larger either in percentage of the character width or in pixels,
        depending on the selected spacing type.

        **See also** **letterSpacing** (), **letterSpacingType** (), and
        **setWordSpacing** ().
        """
        ...

    def letterSpacingType(self) -> "QFont.SpacingType":
        """
        https://doc.qt.io/qt-6/qfont.html#letterSpacingType

        **QFont::SpacingType QFont::letterSpacingType() const**

        Returns the spacing type used for letter spacing.

        **See also** **letterSpacing** (), **setLetterSpacing** (), and
        **setWordSpacing** ().
        """
        ...

    def letterSpacing(self) -> float:
        """
        https://doc.qt.io/qt-6/qfont.html#letterSpacing

        **qreal QFont::letterSpacing() const**

        Returns the letter spacing for the font.

        **See also** **setLetterSpacing** (), **letterSpacingType** (), and
        **setWordSpacing** ().
        """
        ...

    def setItalic(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setItalic

        **void QFont::setItalic(bool enable )**

        Sets the **style** () of the font to **QFont::StyleItalic**  if
        **enable** is true; otherwise the style is set to **QFont::StyleNormal**
        .

        **Note:** If **styleName** () is set, this value may be ignored, or if
        supported on the platform, the font may be rendered tilted instead of
        picking a designed italic font-variant.

        **See also** **italic** () and **QFontInfo** .
        """
        ...

    def italic(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#italic

        **bool QFont::italic() const**

        Returns `true` if the **style** () of the font is not
        **QFont::StyleNormal**

        **See also** **setItalic** () and **style** ().
        """
        ...

    def setBold(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setBold

        **void QFont::setBold(bool enable )**

        If **enable** is true sets the font's weight to **QFont::Bold** ;
        otherwise sets the weight to **QFont::Normal** .

        For finer boldness control use **setWeight** ().

        **Note:** If **styleName** () is set, this value may be ignored, or if
        supported on the platform, the font artificially embolded.

        **See also** **bold** () and **setWeight** ().
        """
        ...

    def bold(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#bold

        **bool QFont::bold() const**

        Returns `true` if **weight** () is a value greater than
        **QFont::Medium** ; otherwise returns `false`.

        **See also** **weight** (), **setBold** (), and **QFontInfo::bold** ().
        """
        ...

    def resolve(self, a0: "QFont") -> "QFont":
        """
        https://doc.qt.io/qt-6/qfont.html#resolve

        **QFont QFont::resolve(const QFont & other ) const**

        Returns a new **QFont**  that has attributes copied from **other** that
        have not been previously set on this font.
        """
        ...

    def defaultFamily(self) -> str:
        """
        https://doc.qt.io/qt-6/qfont.html#defaultFamily

        **QString QFont::defaultFamily() const**

        Returns the family name that corresponds to the current style hint.

        **See also** **StyleHint** , **styleHint** (), and **setStyleHint** ().
        """
        ...

    @staticmethod
    def cacheStatistics() -> None:
        ...

    @staticmethod
    def cleanup() -> None:
        ...

    @staticmethod
    def initialize() -> None:
        ...

    @staticmethod
    def removeSubstitutions(a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#removeSubstitutions

        **[static, since 5.0] void QFont::removeSubstitutions(const QString &
        familyName )**

        Removes all the substitutions for **familyName**.

        This function was introduced in Qt 5.0.

        **See also** **insertSubstitutions** (), **insertSubstitution** (),
        **substitutions** (), and **substitute** ().
        """
        ...

    @staticmethod
    def insertSubstitutions(a0: str, a1: typing.Iterable[str]) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#insertSubstitutions

        **[static] void QFont::insertSubstitutions(const QString & familyName ,
        const QStringList & substituteNames )**

        Inserts the list of families **substituteNames** into the substitution
        list for **familyName**.

        After substituting a font, trigger the updating of the font by
        destroying and re-creating all **QFont**  objects.

        **See also** **insertSubstitution** (), **removeSubstitutions** (),
        **substitutions** (), and **substitute** ().
        """
        ...

    @staticmethod
    def insertSubstitution(a0: str, a1: str) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#insertSubstitution

        **[static] void QFont::insertSubstitution(const QString & familyName ,
        const QString & substituteName )**

        Inserts **substituteName** into the substitution table for the family
        **familyName**.

        After substituting a font, trigger the updating of the font by
        destroying and re-creating all **QFont**  objects.

        **See also** **insertSubstitutions** (), **removeSubstitutions** (),
        **substitutions** (), **substitute** (), and **substitutes** ().
        """
        ...

    @staticmethod
    def substitutions() -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfont.html#substitutions

        **[static] QStringList QFont::substitutions()**

        Returns a sorted list of substituted family names.

        **See also** **insertSubstitution** (), **removeSubstitutions** (), and
        **substitute** ().
        """
        ...

    @staticmethod
    def substitutes(a0: str) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qfont.html#substitutes

        **[static] QStringList QFont::substitutes(const QString & familyName )**

        Returns a list of family names to be used whenever **familyName** is
        specified. The lookup is case insensitive.

        If there is no substitution for **familyName** , an empty list is
        returned.

        **See also** **substitute** (), **insertSubstitutions** (),
        **insertSubstitution** (), and **removeSubstitutions** ().
        """
        ...

    @staticmethod
    def substitute(a0: str) -> str:
        """
        https://doc.qt.io/qt-6/qfont.html#substitute

        **[static] QString QFont::substitute(const QString & familyName )**

        Returns the first family name to be used whenever **familyName** is
        specified. The lookup is case insensitive.

        If there is no substitution for **familyName** , **familyName** is
        returned.

        To obtain a list of substitutions use **substitutes** ().

        **See also** **setFamily** (), **insertSubstitutions** (),
        **insertSubstitution** (), and **removeSubstitutions** ().
        """
        ...

    def fromString(self, a0: str) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#fromString

        **bool QFont::fromString(const QString & descrip )**

        Sets this font to match the description **descrip**. The description is
        a comma-separated list of the font attributes, as returned by
        **toString** ().

        **See also** **toString** ().
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qfont.html#toString

        **QString QFont::toString() const**

        Returns a description of the font. The description is a comma-separated
        list of the attributes, perfectly suited for use in **QSettings** , and
        consists of the following:

        * Font family
          * Point size
          * Pixel size
          * Style hint
          * Font
        weight
          * Font style
          * Underline
          * Strike out
          * Fixed pitch
          *
        Always **0**
          * Capitalization
          * Letter spacing
          * Word spacing
          *
        Stretch
          * Style strategy
          * Font style (omitted when unavailable)

        **See also** **fromString** ().
        """
        ...

    def key(self) -> str:
        """
        https://doc.qt.io/qt-6/qfont.html#key

        **QString QFont::key() const**

        Returns the font's key, a textual representation of a font. It is
        typically used as the key for a cache or dictionary of fonts.

        **See also** **QMap** .
        """
        ...

    def isCopyOf(self, a0: "QFont") -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#isCopyOf

        **bool QFont::isCopyOf(const QFont & f ) const**

        Returns `true` if this font and **f** are copies of each other, i.e. one
        of them was created as a copy of the other and neither has been modified
        since. This is much stricter than equality.

        **See also** **operator=** () and **operator==** ().
        """
        ...

    def exactMatch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#exactMatch

        **bool QFont::exactMatch() const**

        Returns `true` if a window system font exactly matching the settings of
        this font is available.

        **See also** **QFontInfo** .
        """
        ...

    def setStretch(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setStretch

        **void QFont::setStretch(int factor )**

        Sets the stretch factor for the font.

        The stretch factor matches a condensed or expanded version of the font
        or applies a stretch transform that changes the width of all characters
        in the font by **factor** percent. For example, setting **factor** to
        150 results in all characters in the font being 1.5 times (ie. 150%)
        wider. The minimum stretch factor is 1, and the maximum stretch factor
        is 4000. The default stretch factor is `AnyStretch`, which will accept
        any stretch factor and not apply any transform on the font.

        The stretch factor is only applied to outline fonts. The stretch factor
        is ignored for bitmap fonts.

        **Note:** When matching a font with a native non-default stretch factor,
        requesting a stretch of 100 will stretch it back to a medium width font.

        **See also** **stretch** () and **QFont::Stretch** .
        """
        ...

    def stretch(self) -> int:
        """
        https://doc.qt.io/qt-6/qfont.html#stretch

        **int QFont::stretch() const**

        Returns the stretch factor for the font.

        **See also** **setStretch** ().
        """
        ...

    def setStyleStrategy(self, s: "QFont.StyleStrategy") -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setStyleStrategy

        **void QFont::setStyleStrategy(QFont::StyleStrategy s )**

        Sets the style strategy for the font to **s**.

        **See also** **styleStrategy** () and **QFont::StyleStrategy** .
        """
        ...

    def setStyleHint(
        self, hint: "QFont.StyleHint", strategy: "QFont.StyleStrategy" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setStyleHint

        **void QFont::setStyleHint(QFont::StyleHint hint , QFont::StyleStrategy
        strategy = PreferDefault)**

        Sets the style hint and strategy to **hint** and **strategy** ,
        respectively.

        If these aren't set explicitly the style hint will default to `AnyStyle`
        and the style strategy to `PreferDefault`.

        Qt does not support style hints on X11 since this information is not
        provided by the window system.

        **See also** **StyleHint** , **styleHint** (), **StyleStrategy** ,
        **styleStrategy** (), and **QFontInfo** .
        """
        ...

    def styleStrategy(self) -> "QFont.StyleStrategy":
        """
        https://doc.qt.io/qt-6/qfont.html#styleStrategy

        **QFont::StyleStrategy QFont::styleStrategy() const**

        Returns the **StyleStrategy** .

        The style strategy affects the **font matching**  algorithm. See
        **QFont::StyleStrategy**  for the list of available strategies.

        **See also** **setStyleStrategy** (), **setStyleHint** (), and
        **QFont::StyleHint** .
        """
        ...

    def styleHint(self) -> "QFont.StyleHint":
        """
        https://doc.qt.io/qt-6/qfont.html#styleHint

        **QFont::StyleHint QFont::styleHint() const**

        Returns the **StyleHint** .

        The style hint affects the **font matching algorithm** . See
        **QFont::StyleHint**  for the list of available hints.

        **See also** **setStyleHint** (), **QFont::StyleStrategy** , and
        **QFontInfo::styleHint** ().
        """
        ...

    def setKerning(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setKerning

        **void QFont::setKerning(bool enable )**

        Enables kerning for this font if **enable** is true; otherwise disables
        it. By default, kerning is enabled.

        When kerning is enabled, glyph metrics do not add up anymore, even for
        Latin text. In other words, the assumption that width('a') + width('b')
        is equal to width("ab") is not necessarily true.

        **See also** **kerning** () and **QFontMetrics** .
        """
        ...

    def kerning(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#kerning

        **bool QFont::kerning() const**

        Returns `true` if kerning should be used when drawing text with this
        font.

        **See also** **setKerning** ().
        """
        ...

    def setFixedPitch(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setFixedPitch

        **void QFont::setFixedPitch(bool enable )**

        If **enable** is true, sets fixed pitch on; otherwise sets fixed pitch
        off.

        **See also** **fixedPitch** () and **QFontInfo** .
        """
        ...

    def fixedPitch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#fixedPitch

        **bool QFont::fixedPitch() const**

        Returns `true` if fixed pitch has been set; otherwise returns `false`.

        **See also** **setFixedPitch** () and **QFontInfo::fixedPitch** ().
        """
        ...

    def setStrikeOut(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setStrikeOut

        **void QFont::setStrikeOut(bool enable )**

        If **enable** is true, sets strikeout on; otherwise sets strikeout off.

        **See also** **strikeOut** () and **QFontInfo** .
        """
        ...

    def strikeOut(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#strikeOut

        **bool QFont::strikeOut() const**

        Returns `true` if strikeout has been set; otherwise returns `false`.

        **See also** **setStrikeOut** ().
        """
        ...

    def setOverline(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setOverline

        **void QFont::setOverline(bool enable )**

        If **enable** is true, sets overline on; otherwise sets overline off.

        **See also** **overline** () and **QFontInfo** .
        """
        ...

    def overline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#overline

        **bool QFont::overline() const**

        Returns `true` if overline has been set; otherwise returns `false`.

        **See also** **setOverline** ().
        """
        ...

    def setUnderline(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setUnderline

        **void QFont::setUnderline(bool enable )**

        If **enable** is true, sets underline on; otherwise sets underline off.

        **See also** **underline** () and **QFontInfo** .
        """
        ...

    def underline(self) -> bool:
        """
        https://doc.qt.io/qt-6/qfont.html#underline

        **bool QFont::underline() const**

        Returns `true` if underline has been set; otherwise returns `false`.

        **See also** **setUnderline** ().
        """
        ...

    def style(self) -> "QFont.Style":
        """
        https://doc.qt.io/qt-6/qfont.html#style

        **QFont::Style QFont::style() const**

        Returns the style of the font.

        **See also** **setStyle** ().
        """
        ...

    def setStyle(self, style: "QFont.Style") -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setStyle

        **void QFont::setStyle(QFont::Style style )**

        Sets the style of the font to **style**.

        **See also** **style** (), **italic** (), and **QFontInfo** .
        """
        ...

    def setWeight(self, weight: int) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setWeight

        **void QFont::setWeight(QFont::Weight weight )**

        Sets the weight of the font to **weight** , using the scale defined by
        **QFont::Weight**  enumeration.

        **Note:** If **styleName** () is set, this value may be ignored for font
        selection.

        **See also** **weight** () and **QFontInfo** .
        """
        ...

    def weight(self) -> int:
        """
        https://doc.qt.io/qt-6/qfont.html#weight

        **QFont::Weight QFont::weight() const**

        Returns the weight of the font, using the same scale as the
        **QFont::Weight**  enumeration.

        **See also** **setWeight** (), **Weight** , and **QFontInfo** .
        """
        ...

    def setPixelSize(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setPixelSize

        **void QFont::setPixelSize(int pixelSize )**

        Sets the font size to **pixelSize** pixels.

        Using this function makes the font device dependent. Use
        **setPointSize** () or **setPointSizeF** () to set the size of the font
        in a device independent manner.

        **See also** **pixelSize** ().
        """
        ...

    def pixelSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qfont.html#pixelSize

        **int QFont::pixelSize() const**

        Returns the pixel size of the font if it was set with **setPixelSize**
        (). Returns -1 if the size was set with **setPointSize** () or
        **setPointSizeF** ().

        **See also** **setPixelSize** (), **pointSize** (),
        **QFontInfo::pointSize** (), and **QFontInfo::pixelSize** ().
        """
        ...

    def setPointSizeF(self, a0: float) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setPointSizeF

        **void QFont::setPointSizeF(qreal pointSize )**

        Sets the point size to **pointSize**. The point size must be greater
        than zero. The requested precision may not be achieved on all platforms.

        **See also** **pointSizeF** (), **setPointSize** (), and
        **setPixelSize** ().
        """
        ...

    def pointSizeF(self) -> float:
        """
        https://doc.qt.io/qt-6/qfont.html#pointSizeF

        **qreal QFont::pointSizeF() const**

        Returns the point size of the font. Returns -1 if the font size was
        specified in pixels.

        **See also** **pointSize** (), **setPointSizeF** (), **pixelSize** (),
        **QFontInfo::pointSize** (), and **QFontInfo::pixelSize** ().
        """
        ...

    def setPointSize(self, a0: int) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setPointSize

        **void QFont::setPointSize(int pointSize )**

        Sets the point size to **pointSize**. The point size must be greater
        than zero.

        **See also** **pointSize** () and **setPointSizeF** ().
        """
        ...

    def pointSize(self) -> int:
        """
        https://doc.qt.io/qt-6/qfont.html#pointSize

        **int QFont::pointSize() const**

        Returns the point size of the font. Returns -1 if the font size was
        specified in pixels.

        **See also** **setPointSize** () and **pointSizeF** ().
        """
        ...

    def setFamily(self, a0: str) -> None:
        """
        https://doc.qt.io/qt-6/qfont.html#setFamily

        **void QFont::setFamily(const QString & family )**

        Sets the family name of the font. The name is case insensitive and may
        include a foundry name.

        The **family** name may optionally also include a foundry name, e.g.
        "Helvetica [Cronyx]". If the **family** is available from more than one
        foundry and the foundry isn't specified, an arbitrary foundry is chosen.
        If the family isn't available a family will be set using the **font
        matching**  algorithm.

        This will split the family string on a comma and call **setFamilies** ()
        with the resulting list. To preserve a font that uses a comma in it's
        name then use **setFamilies** () directly. From Qt 6.2 this behavior
        will no longer happen and **family** will be passed as a single family.

        **See also** **family** (), **setStyleHint** (), **setFamilies** (),
        **families** (), and **QFontInfo** .
        """
        ...

    def family(self) -> str:
        """
        https://doc.qt.io/qt-6/qfont.html#family

        **QString QFont::family() const**

        Returns the requested font family name. This will always be the same as
        the first entry in the **families** () call.

        **See also** **setFamily** (), **substitutes** (), **substitute** (),
        **setFamilies** (), and **families** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothServiceDiscoveryAgent(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html

    **Detailed Description**

    The discovery process relies on the Bluetooth Service Discovery Process
    (SDP). The following steps are required to query the services provided by
    all contactable Bluetooth devices:

    * create an instance of QBluetoothServiceDiscoveryAgent,
      * connect to
    either the **serviceDiscovered** () or **finished** () signals,
      * and call
    **start** ().

    void MyClass::startServiceDiscovery()
        {

            // Create a
    discovery agent and connect to its signals
    **QBluetoothServiceDiscoveryAgent**  *discoveryAgent = new
    **QBluetoothServiceDiscoveryAgent** (this);
            connect(discoveryAgent,
    SIGNAL(serviceDiscovered(**QBluetoothServiceInfo** )),
                    this,
    SLOT(serviceDiscovered(**QBluetoothServiceInfo** )));

            // Start
    a discovery
            discoveryAgent->start();

            //...
        }
    // In your local slot, read information about the found devices
        void
    MyClass::serviceDiscovered(const **QBluetoothServiceInfo**  &service)
        {
    **qDebug** () << "Found new service:" << service.serviceName()
    << '(' << service.device().address().toString() << ')';
        }

    By default a minimal service discovery is performed. In this mode, the
    returned **QBluetoothServiceInfo**  objects are guaranteed to contain only
    device and service UUID information. Depending on platform and device
    capabilities, other service information may also be available. The minimal
    service discovery mode relies on cached SDP data of the platform. Therefore
    it is possible that this discovery does not find a device although it is
    physically available. In such cases a full discovery must be performed to
    force an update of the platform cache. However for most use cases a minimal
    discovery is adequate as it is much quicker and other classes which require
    up-to-date information such as **QBluetoothSocket::connectToService** ()
    will perform additional discovery if required. If the full service
    information is required, pass **FullDiscovery**  as the discoveryMode
    parameter to **start** ().

    This class may internally utilize **QBluetoothDeviceDiscoveryAgent**  to
    find unknown devices.

    The service discovery may find Bluetooth Low Energy services too if the
    target device is a combination of a classic and Low Energy device. Those
    devices are required to advertise their Low Energy services via SDP. If the
    target device only supports Bluetooth Low Energy services, it is likely to
    not advertise them via SDP. The **QLowEnergyController**  class should be
    utilized to perform the service discovery on Low Energy devices.

    On iOS, this class cannot be used because the platform does not expose an
    API which may permit access to QBluetoothServiceDiscoveryAgent related
    features.

    **See also** **QBluetoothDeviceDiscoveryAgent**  and
    **QLowEnergyController** .
    """

    class DiscoveryMode(enum.Enum):
        MinimalDiscovery: QBluetoothServiceDiscoveryAgent = ...
        FullDiscovery: QBluetoothServiceDiscoveryAgent = ...

    class Error(enum.Enum):
        NoError: QBluetoothServiceDiscoveryAgent = ...
        InputOutputError: QBluetoothServiceDiscoveryAgent = ...
        PoweredOffError: QBluetoothServiceDiscoveryAgent = ...
        InvalidBluetoothAdapterError: QBluetoothServiceDiscoveryAgent = ...
        UnknownError: QBluetoothServiceDiscoveryAgent = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#QBluetoothSe
        rviceDiscoveryAgent

        **QBluetoothServiceDiscoveryAgent::QBluetoothServiceDiscoveryAgent(QObje
        ct * parent = nullptr)**

        Constructs a new QBluetoothServiceDiscoveryAgent with **parent**. The
        search is performed via the local default Bluetooth adapter.
        """
        ...

    @typing.overload
    def __init__(
        self,
        deviceAdapter: QBluetoothAddress,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#QBluetoothSe
        rviceDiscoveryAgent-1

        **QBluetoothServiceDiscoveryAgent::QBluetoothServiceDiscoveryAgent(const
        QBluetoothAddress & deviceAdapter , QObject * parent = nullptr)**

        Constructs a new QBluetoothServiceDiscoveryAgent for **deviceAdapter**
        and with **parent**.

        It uses **deviceAdapter** for the service search. If **deviceAdapter**
        is default constructed the resulting QBluetoothServiceDiscoveryAgent
        object will use the local default Bluetooth adapter.

        If a **deviceAdapter** is specified that is not a local adapter
        **error** () will be set to **InvalidBluetoothAdapterError** . Therefore
        it is recommended to test the error flag immediately after using this
        constructor.

        **Note:** On WinRT the passed adapter address will be ignored.

        **Note:** On Android passing any **deviceAdapter** address is
        meaningless as Android 6.0 or later does not publish the local Bluetooth
        address anymore. Subsequently, the passed adapter address can never be
        matched against the local adapter address. Therefore the subsequent call
        to **start** () will always trigger **InvalidBluetoothAdapterError** .

        **See also** **error** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#clear

        **[slot] void QBluetoothServiceDiscoveryAgent::clear()**

        Clears the results of previous service discoveries and resets
        **uuidFilter** (). This function does nothing during an ongoing service
        discovery (see **isActive** ()).

        **See also** **discoveredServices** ().
        """
        ...

    def stop(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#stop

        **[slot] void QBluetoothServiceDiscoveryAgent::stop()**

        Stops the service discovery process. The **canceled** () signal will be
        emitted once the search has stopped.
        """
        ...

    def start(
        self, mode: "QBluetoothServiceDiscoveryAgent.DiscoveryMode" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#start

        **[slot] void QBluetoothServiceDiscoveryAgent::start(QBluetoothServiceDi
        scoveryAgent::DiscoveryMode mode = MinimalDiscovery)**

        Starts service discovery. **mode** specifies the type of service
        discovery to perform.

        On some platforms, device discovery may lead to pairing requests.

        **See also** **DiscoveryMode** .
        """
        ...

    def remoteAddress(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#remoteAddres
        s

        **QBluetoothAddress QBluetoothServiceDiscoveryAgent::remoteAddress()
        const**

        Returns the remote device address. If **setRemoteAddress** () is not
        called, the function will return a default constructed
        **QBluetoothAddress** .

        **See also** **setRemoteAddress** ().
        """
        ...

    def setRemoteAddress(self, address: QBluetoothAddress) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#setRemoteAdd
        ress

        **bool QBluetoothServiceDiscoveryAgent::setRemoteAddress(const
        QBluetoothAddress & address )**

        Sets the remote device address to **address**. If **address** is default
        constructed, services will be discovered on all contactable Bluetooth
        devices. A new remote address can only be set while there is no service
        discovery in progress; otherwise this function returns false.

        On some platforms the service discovery might lead to pairing requests.
        Therefore it is not recommended to do service discoveries on all
        devices. This function can be used to restrict the service discovery to
        a particular device.

        **See also** **remoteAddress** ().
        """
        ...

    def uuidFilter(self) -> typing.List["QBluetoothUuid"]:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#uuidFilter

        **QList<QBluetoothUuid> QBluetoothServiceDiscoveryAgent::uuidFilter()
        const**

        Returns the UUID filter.

        **See also** **setUuidFilter** ().
        """
        ...

    @typing.overload
    def setUuidFilter(self, uuids: typing.Iterable["QBluetoothUuid"]) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#setUuidFilte
        r

        **void QBluetoothServiceDiscoveryAgent::setUuidFilter(const
        QList<QBluetoothUuid> & uuids )**

        Sets the UUID filter to **uuids**. Only services matching the UUIDs in
        **uuids** will be returned. The matching applies to the service's
        **ServiceId**  and **ServiceClassIds**  attributes.

        An empty UUID list is equivalent to a list containing only
        **QBluetoothUuid::ServiceClassUuid::PublicBrowseGroup** .

        **See also** **uuidFilter** ().
        """
        ...

    @typing.overload
    def setUuidFilter(self, uuid: "QBluetoothUuid") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#setUuidFilte
        r-1

        **void QBluetoothServiceDiscoveryAgent::setUuidFilter(const
        QBluetoothUuid & uuid )**

        This is an overloaded member function, provided for convenience.

        Sets the UUID filter to a list containing the single element **uuid**.
        The matching applies to the service's **ServiceId**  and
        **ServiceClassIds**  attributes.

        **See also** **uuidFilter** ().
        """
        ...

    def discoveredServices(self) -> typing.List["QBluetoothServiceInfo"]:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#discoveredSe
        rvices

        **QList<QBluetoothServiceInfo>
        QBluetoothServiceDiscoveryAgent::discoveredServices() const**

        Returns the list of all discovered services.

        This list of services accumulates newly discovered services from
        multiple calls to **start** (). Unless **clear** () is called the list
        cannot decrease in size. This implies that if a remote Bluetooth device
        moves out of range in between two subsequent calls to **start** () the
        list may contain stale entries.

        **Note:** The list of services should always be cleared before the
        discovery mode is changed.

        **See also** **clear** ().
        """
        ...

    def errorString(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#errorString

        **QString QBluetoothServiceDiscoveryAgent::errorString() const**

        Returns a human-readable description of the last error that occurred
        during the service discovery.
        """
        ...

    def error(self) -> "QBluetoothServiceDiscoveryAgent.Error":
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#error

        **QBluetoothServiceDiscoveryAgent::Error
        QBluetoothServiceDiscoveryAgent::error() const**

        Returns the type of error that last occurred. If the service discovery
        is done for a single **remoteAddress** () it will return errors that
        occurred while trying to discover services on that device. If the
        **remoteAddress** () is not set and devices are discovered by a scan,
        errors during service discovery on individual devices are not saved and
        no signals are emitted. In this case, errors are fairly normal as some
        devices may not respond to discovery or may no longer be in range. Such
        errors are surpressed. If no services are returned, it can be assumed no
        services could be discovered.
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#isActive

        **bool QBluetoothServiceDiscoveryAgent::isActive() const**

        Returns `true` if the service discovery is currently active; otherwise
        returns `false`. An active discovery can be stopped by calling **stop**
        ().
        """
        ...

    @property
    def canceled(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#canceled

        **[signal] void QBluetoothServiceDiscoveryAgent::canceled()**

        This signal is triggered when the service discovery was canceled via a
        call to **stop** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#errorOccurre
        d

        **[signal, since 6.2] void QBluetoothServiceDiscoveryAgent::errorOccurre
        d(QBluetoothServiceDiscoveryAgent::Error error )**

        This signal is emitted when an **error** occurs. The **error** parameter
        describes the error that occurred.

        This function was introduced in Qt 6.2.
        """
        ...

    @property
    def finished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#finished

        **[signal] void QBluetoothServiceDiscoveryAgent::finished()**

        This signal is emitted when the Bluetooth service discovery completes.

        Unlike the **QBluetoothDeviceDiscoveryAgent::finished** () signal this
        signal will even be emitted when an error occurred during the service
        discovery. Therefore it is recommended to check the **error** () signal
        to evaluate the success of the service discovery discovery.
        """
        ...

    @property
    def serviceDiscovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothservicediscoveryagent.html#serviceDisco
        vered

        **[signal] void QBluetoothServiceDiscoveryAgent::serviceDiscovered(const
        QBluetoothServiceInfo & info )**

        This signal is emitted when the Bluetooth service described by **info**
        is discovered.

        **Note:** The passed **QBluetoothServiceInfo**  parameter may contain a
        Bluetooth Low Energy service if the target device advertises the service
        via SDP. This is required from device which support both, classic
        Bluetooth (BaseRate) and Low Energy services.

        **See also** **QBluetoothDeviceInfo::coreConfigurations** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtCore
from PyQt6.QtNfc import *
import enum


class QNdefNfcSmartPosterRecord(QNdefRecord):
    """
    https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html

    **Detailed Description**

    RTD-SmartPoster encapsulates a Smart Poster.
    """

    class Action(enum.Enum):
        UnspecifiedAction: QNdefNfcSmartPosterRecord = ...
        DoAction: QNdefNfcSmartPosterRecord = ...
        SaveAction: QNdefNfcSmartPosterRecord = ...
        EditAction: QNdefNfcSmartPosterRecord = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#QNdefNfcSmartPoste
        rRecord

        **QNdefNfcSmartPosterRecord::QNdefNfcSmartPosterRecord()**

        Constructs a new empty smart poster.
        """
        ...

    @typing.overload
    def __init__(self, other: "QNdefNfcSmartPosterRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#QNdefNfcSmartPoste
        rRecord-1

        **QNdefNfcSmartPosterRecord::QNdefNfcSmartPosterRecord(const QNdefRecord
        & other )**

        Constructs a new smart poster that is a copy of **other**.
        """
        ...

    @typing.overload
    def __init__(self, other: QNdefRecord) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#QNdefNfcSmartPoste
        rRecord-2

        **QNdefNfcSmartPosterRecord::QNdefNfcSmartPosterRecord(const
        QNdefNfcSmartPosterRecord & other )**

        Constructs a new smart poster that is a copy of **other**.
        """
        ...

    def setTypeInfo(self, type: str) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setTypeInfo

        **void QNdefNfcSmartPosterRecord::setTypeInfo(const QString & type )**

        Sets the type record to **type**. **type** describes the type of the
        object referenced by **uri** ().

        **See also** **typeInfo** ().
        """
        ...

    def typeInfo(self) -> str:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#typeInfo

        **QString QNdefNfcSmartPosterRecord::typeInfo() const**

        Returns the MIME type that describes the type of the objects that can be
        reached via **uri** ().

        If the type is not known, the returned **QString**  is empty.

        **See also** **setTypeInfo** () and **hasTypeInfo** ().
        """
        ...

    def setSize(self, size: int) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setSize

        **void QNdefNfcSmartPosterRecord::setSize(quint32 size )**

        Sets the record **size**. The value contains the size in bytes of the
        object that the URI refers to.

        **See also** **size** () and **hasSize** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#size

        **quint32 QNdefNfcSmartPosterRecord::size() const**

        Returns the size from the size record if available; otherwise returns 0.

        The value is optional and contains the size in bytes of the object that
        the URI refers to. It may be used by the device to determine whether it
        can accommodate the object.

        **See also** **setSize** ().
        """
        ...

    def setIcons(self, icons: typing.Iterable[QNdefNfcIconRecord]) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setIcons

        **void QNdefNfcSmartPosterRecord::setIcons(const
        QList<QNdefNfcIconRecord> & icons )**

        Adds the icon record list **icons** to the smart poster. Any existing
        records are overwritten.

        **See also** **hasIcon** () and **icon** ().
        """
        ...

    @typing.overload
    def removeIcon(self, icon: QNdefNfcIconRecord) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#removeIcon

        **bool QNdefNfcSmartPosterRecord::removeIcon(const QNdefNfcIconRecord &
        icon )**

        Attempts to remove the icon record **icon** from the smart poster.
        Removes the record and returns `true` if the smart poster contains a
        matching record, otherwise `false` is returned.
        """
        ...

    @typing.overload
    def removeIcon(self, type: QtCore.QByteArray) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#removeIcon-1

        **bool QNdefNfcSmartPosterRecord::removeIcon(const QByteArray & type )**

        Attempts to remove the icon record with the type **type** from the smart
        poster. Removes the record and returns `true` if the smart poster
        contains a matching record, otherwise `false` is returned.
        """
        ...

    @typing.overload
    def addIcon(self, icon: QNdefNfcIconRecord) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#addIcon

        **void QNdefNfcSmartPosterRecord::addIcon(const QNdefNfcIconRecord &
        icon )**

        Adds an icon record **icon** to the smart poster. If the smart poster
        already contains an icon record with the same type then the existing
        icon record is replaced.
        """
        ...

    @typing.overload
    def addIcon(self, type: QtCore.QByteArray, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#addIcon-1

        **void QNdefNfcSmartPosterRecord::addIcon(const QByteArray & type ,
        const QByteArray & data )**

        Adds an icon record with type **type** and data **data** to the smart
        poster. If the smart poster already contains an icon record with the
        same type then the existing icon record is replaced.
        """
        ...

    def iconRecords(self) -> typing.List[QNdefNfcIconRecord]:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#iconRecords

        **QList<QNdefNfcIconRecord> QNdefNfcSmartPosterRecord::iconRecords()
        const**

        Returns a copy of all icon records inside the smart poster.
        """
        ...

    def iconRecord(self, index: int) -> QNdefNfcIconRecord:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#iconRecord

        **QNdefNfcIconRecord QNdefNfcSmartPosterRecord::iconRecord(qsizetype
        index ) const**

        Returns the icon record corresponding to the index **index** inside the
        smart poster, where **index** is a value between 0 and **iconCount** ()
        - 1. Values outside of this range return an empty record.
        """
        ...

    def icon(self, mimetype: QtCore.QByteArray = ...) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#icon

        **QByteArray QNdefNfcSmartPosterRecord::icon(const QByteArray & mimetype
        = QByteArray()) const**

        Returns the associated icon record data if the smart poster contains an
        icon record with MIME type **mimetype**. If **mimetype** is omitted or
        empty then the first icon's record data is returned. In all other cases,
        an empty array is returned.
        """
        ...

    def iconCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#iconCount

        **qsizetype QNdefNfcSmartPosterRecord::iconCount() const**

        Returns the number of icon records contained inside the smart poster.
        """
        ...

    def setAction(self, act: "QNdefNfcSmartPosterRecord.Action") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setAction

        **void
        QNdefNfcSmartPosterRecord::setAction(QNdefNfcSmartPosterRecord::Action
        act )**

        Sets the action record to **act**

        **See also** **action** ().
        """
        ...

    def action(self) -> "QNdefNfcSmartPosterRecord.Action":
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#action

        **QNdefNfcSmartPosterRecord::Action QNdefNfcSmartPosterRecord::action()
        const**

        Returns the action from the action record if available. Otherwise
        **UnspecifiedAction**  is returned.

        **See also** **setAction** ().
        """
        ...

    @typing.overload
    def setUri(self, url: "QNdefNfcUriRecord") -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setUri

        **void QNdefNfcSmartPosterRecord::setUri(const QNdefNfcUriRecord & url
        )**

        Sets the URI record to **url**

        **See also** **uri** ().
        """
        ...

    @typing.overload
    def setUri(self, url: QtCore.QUrl) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setUri-1

        **void QNdefNfcSmartPosterRecord::setUri(const QUrl & url )**

        Constructs a URI record and sets its content inside the smart poster to
        **url**
        """
        ...

    def uriRecord(self) -> "QNdefNfcUriRecord":
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#uriRecord

        **QNdefNfcUriRecord QNdefNfcSmartPosterRecord::uriRecord() const**

        Returns the smart poster's URI record if set. Otherwise an empty URI is
        returned.
        """
        ...

    def uri(self) -> QtCore.QUrl:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#uri

        **QUrl QNdefNfcSmartPosterRecord::uri() const**

        Returns the URI from the smart poster's URI record if set. Otherwise an
        empty URI is returned.

        **See also** **setUri** ().
        """
        ...

    def setTitles(self, titles: typing.Iterable["QNdefNfcTextRecord"]) -> None:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#setTitles

        **void QNdefNfcSmartPosterRecord::setTitles(const
        QList<QNdefNfcTextRecord> & titles )**

        Adds the title record list **titles** to the smart poster. Any existing
        records are overwritten.
        """
        ...

    @typing.overload
    def removeTitle(self, text: "QNdefNfcTextRecord") -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#removeTitle

        **bool QNdefNfcSmartPosterRecord::removeTitle(const QNdefNfcTextRecord &
        text )**

        Attempts to remove the title record **text** from the smart poster.
        Removes the record and returns `true` if the smart poster contains a
        matching record, otherwise `false` is returned.
        """
        ...

    @typing.overload
    def removeTitle(self, locale: str) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#removeTitle-1

        **bool QNdefNfcSmartPosterRecord::removeTitle(const QString & locale )**

        Attempts to remove a title record with the locale **locale** from the
        smart poster. Removes the record and returns `true` if the smart poster
        contains a matching record, otherwise `false` is returned.
        """
        ...

    @typing.overload
    def addTitle(self, text: "QNdefNfcTextRecord") -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#addTitle

        **bool QNdefNfcSmartPosterRecord::addTitle(const QNdefNfcTextRecord &
        text )**

        Attempts to add a title record **text** to the smart poster. If the
        smart poster does not already contain a title record with the same
        locale as title record **text** , then the title record is added and the
        function returns `true`. Otherwise `false` is returned.
        """
        ...

    @typing.overload
    def addTitle(
        self, text: str, locale: str, encoding: "QNdefNfcTextRecord.Encoding"
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#addTitle-1

        **bool QNdefNfcSmartPosterRecord::addTitle(const QString & text , const
        QString & locale , QNdefNfcTextRecord::Encoding encoding )**

        Attempts to add a new title record with title **text** , locale
        **locale** and encoding **encoding**. If the smart poster does not
        already contain a title record with locale **locale** , then the title
        record is added and the function returns `true`. Otherwise `false` is
        returned.
        """
        ...

    def titleRecords(self) -> typing.List["QNdefNfcTextRecord"]:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#titleRecords

        **QList<QNdefNfcTextRecord> QNdefNfcSmartPosterRecord::titleRecords()
        const**

        Returns a copy of all title records inside the smart poster.
        """
        ...

    def titleRecord(self, index: int) -> "QNdefNfcTextRecord":
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#titleRecord

        **QNdefNfcTextRecord QNdefNfcSmartPosterRecord::titleRecord(qsizetype
        index ) const**

        Returns the title record corresponding to the index **index** inside the
        smart poster, where **index** is a value between 0 and **titleCount** ()
        - 1. Values outside of this range return an empty record.
        """
        ...

    def title(self, locale: str = ...) -> str:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#title

        **QString QNdefNfcSmartPosterRecord::title(const QString & locale =
        QString()) const**

        Returns the title record text associated with locale **locale** if
        available. If **locale** is empty then the title text of the first
        available record is returned. In all other cases an empty string is
        returned.
        """
        ...

    def titleCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#titleCount

        **qsizetype QNdefNfcSmartPosterRecord::titleCount() const**

        Returns the number of title records contained inside the smart poster.
        """
        ...

    def hasTypeInfo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#hasTypeInfo

        **bool QNdefNfcSmartPosterRecord::hasTypeInfo() const**

        Returns `true` if the smart poster contains a type record, otherwise
        returns `false`.
        """
        ...

    def hasSize(self) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#hasSize

        **bool QNdefNfcSmartPosterRecord::hasSize() const**

        Returns `true` if the smart poster contains a size record, otherwise
        returns `false`.
        """
        ...

    def hasIcon(self, mimetype: QtCore.QByteArray = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#hasIcon

        **bool QNdefNfcSmartPosterRecord::hasIcon(const QByteArray & mimetype =
        QByteArray()) const**

        Returns `true` if the smart poster contains an icon record using the
        type **mimetype**. If **mimetype** is empty, then `true` is returned if
        the smart poster contains at least one icon record. In all other cases,
        `false` is returned.
        """
        ...

    def hasAction(self) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#hasAction

        **bool QNdefNfcSmartPosterRecord::hasAction() const**

        Returns `true` if the smart poster contains an action record, otherwise
        returns `false`.
        """
        ...

    def hasTitle(self, locale: str = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qndefnfcsmartposterrecord.html#hasTitle

        **bool QNdefNfcSmartPosterRecord::hasTitle(const QString & locale =
        QString()) const**

        Returns `true` if the smart poster contains a title record using the
        locale **locale**. If **locale** is empty, then `true` is returned if
        the smart poster contains at least one title record. In all other cases,
        `false` is returned.
        """
        ...

    def setPayload(self, payload: QtCore.QByteArray) -> None:
        ...
